(function(g){
  //为ie9以下浏览器添加Object.create方法
  if (typeof Object.create !== "function") {
    Object.create = function (proto, propertiesObject) {
      if (typeof proto !== 'object' && typeof proto !== 'function') {
        throw new TypeError('Object prototype may only be an Object: ' + proto);
      } else if (proto === null) {
        throw new Error("This browser's implementation of Object.create is a shim and doesn't support 'null' as the first argument.");
      }
      if (typeof propertiesObject != 'undefined') throw new Error("This browser's implementation of Object.create is a shim and doesn't support a second argument.");
      function F() {}
      F.prototype = proto;
      return new F();
    };
  }
  //curry函数
  var createCurry=function (fn,args) {
    if (args.length>=fn.length) {
      return fn.apply(fn,args);
    }
    return function () {
      if (arguments.length==0) arguments=[null];
      return createCurry(fn,args.concat([].slice.apply(arguments)));
    }
  }
  var curry=function (fn) {
    if(typeof fn !='function') return null;
    return function () {
      if (arguments.length==0) arguments=[null];
      return createCurry(fn,[].slice.apply(arguments));
    }
  };
  //compose函数，从左至右执行
  var flow=function () {
    var args=arguments;
    return function () {
      var x=[].slice.apply(arguments);
      for (var i = 0; i < args.length ; i++) {
        if (typeof args[i] == 'function') {
          x=args[i].apply(null,orz.toArray(x));
        }
      }
      return x;
    }
  };
  var match=curry(function (q,str) {
    return String.prototype.match.call(str,q) || [];
  });
  var replace=curry(function (q,r,str) {
    if (str == null) return str;
    return String.prototype.replace.call(str,q,r);
  });
  var trim=replace(/(^\s*)|(\s*$)/ig,'');
  //用于字符串补位,第一个参数决定是否右补位（否则就是左补位），第二个参数为补位用的字符串，第三个是补位长度，第四个是应用字符串
  var pad=curry(function (right,add,len,str) {
    if (!isExist(right)) right=false;
    if (!isExist(add)) add='0';
    str=parseInt(str);
    if (!isString(str)) str=str+'';
    var needLen=len-str.length;
    var needStr='';
    while(needStr.length<needLen) {
      needStr+=add;
    }
    needStr=needStr.substring(0,needLen);
    return right ? str+needStr : needStr+str;
  });
  //用于检查变量类型
  var checkType=curry(function (type,x) {
    switch (type) {
      case 'array':
        return Object.prototype.toString.call(x) === '[object Array]';
        break;
      case 'object':
        return Object.prototype.toString.call(x) === '[object Object]';
        break;
      case 'regexp':
        return Object.prototype.toString.call(x) === '[object RegExp]';
        break;
      default:
      return typeof x == type;
    }
  });
  var isObject=checkType('object');
  var isFunction=checkType('function');
  var isString=checkType('string');
  var isNumber=checkType('number');
  var isBoolean=checkType('boolean');
  var isArray=checkType('array');
  var isRegExp=checkType('regexp');
  var isExist=function (x) {
    return x!=null;
  };
  var isEmpty=function (x) {
    if(!isExist(x)) return true;
    if(isArray(x)) x=x.toString();
    if(isString(x)) return trim(x).length===0;
    if(isObject(x)) {
      for (var p in x) {
        if (x.hasOwnProperty(p)) {
          return false;
        }
      }
      return true;
    }
    if(Math.abs(x-0)===0) return true;
    return false;
  };
  var isNotEmpty=function (x) {
    return !isEmpty(x);
  };
  var getDocument=curry(function (prop,get) {
    return document.documentElement[prop];
  });
  var clientWidthBigThen=curry(function (w,get) {
    return getDocument('clientWidth','')>=w;
  });
  var isIos=flow(match(/(iPhone|iPod|ios|iPad)/i),isNotEmpty);
  var isAndroid=flow(match(/Android/i),isNotEmpty);
  var isOtherMobile=flow(match(/(phone|pad|pod|iPhone|iPod|ios|iPad|Android|Mobile|BlackBerry|IEMobile|MQQBrowser|JUC|Fennec|wOSBrowser|BrowserNG|WebOS|Symbian|Windows Phone)/i),isNotEmpty);
  var isMobile=function (){
    var u=navigator.userAgent;
    if (isIos(u)) return 'ios';
    if (isAndroid(u)) return 'android';
    if (isOtherMobile(u)) return 'mobile';
    return false;
  };
  var deepCopy=function (sth) {
    var re;
    if (isObject(sth)) {
      re={};
      for (var key in sth) {
        if (sth.hasOwnProperty(key)) {
          re[key]=this.deepCopy(sth[key]);
        }
      }
    }else{
      re=sth;
    }
    return re;
  };
  var toArray=function (sth) {
    var re=[];
    if (isObject(sth)) {
      for (var key in sth) {
        if (sth.hasOwnProperty(key)) {
          if (isObject(sth[key])) {
            re.push(this.toArray(sth[key]));
          }else{
            re.push(sth[key]);
          }
        }
      }
    }else{
      re.push(sth);
    }
    return re;
  };
  var jsonEncode=function (str) {
    return JSON.stringify(str);
  };
  var jsonDecode=function (str) {
    var opt;
    try {
      opt=JSON.parse(str);
    } catch (e) {
      opt=null;
      console.dir(e);
    }
    return opt;
  };
  var isDate=match(/^\d{4}[-\/][01]\d[-\/][0-3]\d(\s+[0-2]\d(:[0-5]\d(:[0-5]\d)?)?)?/gi);
  var dateDiff=function (f,b,a) {
    if (!isString(b) || !isString(a)) {
      console.log('date format is wrong');
      return null;
    }
    a=replace(/\-/g,'/',a);
    b=replace(/\-/g,'/',b);
    b=new Date(b).getTime();
    a=new Date(a).getTime();
    if (isNaN(b) || isNaN(a)) {
      console.log('it is not a date');
      return null;
    }
    var diff=a-b;
    var div=1;
    switch (f) {
      case 'week':
        div=7*24*3600*1000;
        break;
      case 'day':
        div=24*3600*1000;
        break;
      case 'hour':
        div=3600*1000;
        break;
      case 'minute':
        div=60*1000;
        break;
      case 'second':
        div=1000;
        break;
      default:
        div=1;
    }
    return Math.floor(diff/div);
  };
  //获取cookie
  var getCookie=function (name) {
    var arr,reg=new RegExp("(^| )"+name+"=([^;]*)(;|$)");
    if(arr=document.cookie.match(reg)){
      return decodeURIComponent(arr[2]);
    }
    return '';
  };
  //设置cookie
  var setCookie=function (cname,cvalue,exdays,currentPath) {
    if (!isExist(exdays)) exdays=1;
    exdays=exdays-0;
    if(isNaN(exdays)) exdays=1;
    if (!isExist(currentPath)) {
      path=';path=/';
    }else{
      path='';
    }
    var d=new Date();
    d.setTime(d.getTime()+(exdays*24*60*60*1000));
    var expires="expires="+d.toUTCString();
    document.cookie=cname+"="+encodeURIComponent(cvalue)+"; "+expires+path;
  };
  //清除cookie
  var delCookie=function (name) {
    setCookie(name, "", -1);
  };
  var returnTrue=function () {
    return true;
  };
  var returnFalse=function () {
    return false;
  };
  var of=function (x) {
    return function () {
      return x;
    };
  };
  //生成单件对象
  var getSingle=function (fn) {
    var x;
    return function () {
      return x || (x=fn.apply(x,arguments));
    }
  };
  var Lizus={
    curry:curry,
    flow:flow,
    of:of,
    getSingle:getSingle,
    returnFalse:returnFalse,
    returnTrue:returnTrue,
    match:match,
    replace:replace,
    deepCopy:deepCopy,
    toArray:toArray,
    jsonEncode:jsonEncode,
    jsonDecode:jsonDecode,
    lpad:pad(),
    rpad:pad(true),
    getCookie:getCookie,
    setCookie:setCookie,
    delCookie:delCookie,
    isObject:isObject,
    isString:isString,
    isBoolean:isBoolean,
    isNumber:isNumber,
    isArray:isArray,
    isFunction:isFunction,
    isRegExp:isRegExp,
    isExist:isExist,
    isEmpty:isEmpty,
    isNotEmpty:isNotEmpty,
    dateDiff:dateDiff,
    clientWidthBigThen:clientWidthBigThen,
    getDocument:getDocument,
  };
  var lizus=Object.create(Lizus);
  lizus.trim=trim;
  lizus.isMobile=isMobile;
  lizus.sm=clientWidthBigThen(768);
  lizus.md=clientWidthBigThen(992);
  lizus.lg=clientWidthBigThen(1200);
  lizus.st=getDocument('scrollTop');
  lizus.ct=getDocument('clientHeight');
  lizus.cl=getDocument('clientWidth');

  g.orz=lizus;
})(window);

(function(){
  // 补丁
  window.requestAnimationFrame = (function(){
    return  window.requestAnimationFrame       ||
    window.webkitRequestAnimationFrame ||
    window.mozRequestAnimationFrame    ||
    function( callback ){
      window.setTimeout(callback, 1000 / 60);
    };
  })();
  window.cancelAnimationFrame=window.cancelAnimationFrame ||
	Window.webkitCancelAnimationFrame ||
	window.mozCancelAnimationFrame ||
	window.msCancelAnimationFrame ||
	window.oCancelAnimationFrame ||
	function( id ){
		window.clearTimeout( id );
	};

  Function.prototype.bind = function (oThis) {
    if (typeof this !== "function") {
      throw new TypeError("Function.prototype.bind - what is trying to be bound is not callable");
    }

    var aArgs = Array.prototype.slice.call(arguments, 1),
    fToBind = this,
    fNOP = function () {},
    fBound = function () {
      return fToBind.apply(
        this instanceof fNOP && oThis ? this : oThis || window,
        aArgs.concat(Array.prototype.slice.call(arguments))
      );
    };

    fNOP.prototype = this.prototype;
    fBound.prototype = new fNOP();

    return fBound;
  };
})();

(function(){
  orz.trace=orz.curry(function trace(tag,x) {
    orz.log(tag,x);
    return x;
  });
})();

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
console在不同浏览器之间的兼容，需要输出时，统一使用orz.log
在IE下调试的时候，dir经常会出错，替换成log
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function(){
  isChrome=function () {
    var userAgent = navigator.userAgent;
    if (userAgent.indexOf("Edge") > -1){//解决IE假装Chrome的问题
      return false;
    }
    if (userAgent.indexOf("Chrome") > -1){
      return true;
    }
    return false;
  };
  orz.log=function () {
    var opt=Array.prototype.slice.call(arguments,0);
    if (window.console) {
      var fn;
      if(console.info){
        fn=window.console.info;
      }else{
        fn=window.console.log;
      }
      fn.apply(null,opt);
    }else{
      alert(opt);
    }
  };
})();

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name admin-ajax的curry化
 * @Author lizus.com
 * @Updated 20190512
 * @Description

 *
 * @Example

 *
 * @Return

 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  orz.ajax=orz.curry(function (type,error,success,data,context){
    $.ajax({
      type:type,
      url:uisdc.ajax_url,
      context:context,
      data:data,
      success:success,
      error:error
    });
  });
  orz.get=orz.ajax('GET',function (){
    orz.log('ajax get error');
    orz.log(this);
  });
  orz.post=orz.ajax('POST',function (){
    orz.log('ajax post error');
    orz.log(this);
  });
})(jQuery);

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name jQuery获取DOM以data-开头的attr的Curry化
 * @Author lizus.com
 * @Updated 20190512
 * @Description
 使用Curry组织jQuery的DOM元素的属性获取，以data-开头
 *
 * @param attr 属性名
 * @param tag dom对像查询字符串或jQuery对象
 *
 * @Return 获取到的属性值
 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  orz.attr=orz.curry(function (attr,tag){
      return $(tag).attr('data-'+attr);
  });
  orz.setAttr=orz.curry(function (attr,value,tag){
      return $(tag).attr('data-'+attr,value);
  });
  orz.attrEq=orz.curry(function (attr,value,tag){
    return orz.attr(attr,tag) == value;
  });
  orz.addClass=orz.curry(function (className,tag){
    return $(tag).addClass(className);
  });
  orz.removeClass=orz.curry(function (className,tag){
    return $(tag).removeClass(className);
  });
  orz.hasClass=orz.curry(function (className,tag){
    return $(tag).hasClass(className);
  });
})(jQuery);

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name jQuery点击事件函数式Curry化
 * @Author lizus.com
 * @Updated 20190512
 * @Description
 使用Curry组织jQuery的DOM点击事件
 *
 * @param fn 点击事件的处理函数或函数数组
 * @param tag 点击事件的dom对像查询字符串
 *
 * @Return null
 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  orz.click=orz.curry(function (fn,tag){
    if (orz.isArray(fn)) {
      for (var i = 0; i < fn.length; i++) {
        if(orz.isFunction(fn[i])) {
          $('body').on('click',tag,fn[i]);
        }
      }
    }else if(orz.isFunction(fn)){
      $('body').on('click',tag,fn);
    }
  });
})(jQuery);

(function(){
  /* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
  使用帧动画优化动画表现
  传入fn来实现每一帧的动画内容
  使用start开始动画，stop停止
  ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
  orz.animate=function (fn) {
    var id=0,//记录动画的ID
        startTime=0,//记录动画开始的时间
        stopTime=0;//记录动画停止的时间
        hasStart=false;//是否开始动画了
    var animate=function (){
      fn.call(this);
      id = window.requestAnimationFrame(animate);
    };
    return {
      start:function (){
        if (hasStart) return;
        var now=new Date();
        startTime=now.getTime();
        id = window.requestAnimationFrame(animate);
        hasStart=true;
      },
      stop:function () {
        var now=new Date();
        stopTime=now.getTime();
        if (id) {
          window.cancelAnimationFrame(id);
        }
        id=0;
        hasStart=false;
      }
    };
  };
})();

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name 点赞数据的cookie存储及判断
 * @Author lizus.com
 * @Updated 20190513
 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */

(function(){
  /**
   * 从cookie中获取所有已点赞的ID
   * @param   type 点赞类型，目前分文章，读报和评论
   * @return   对应ID数组
   */
  orz.get_zan_cookie=function (type){
    return orz.trim(orz.getCookie(type));
  };
  orz.set_zan_cookie=orz.curry(function (type,id){
    var coo=orz.get_zan_cookie(type);
    if (orz.has_zan_cookie(type,id)) {
      //已点赞的删掉
      //coo=coo.substring(0,index)+coo.substring(index+id.length+1);
    }else {
      coo=coo+','+id;
    }
    coo=orz.trim(coo);
    coo=coo.replace(/^,|,$/,'');
    orz.setCookie(type,coo,365);
  });
  orz.has_zan_cookie=orz.curry(function (type,id){
    var coo=orz.get_zan_cookie(type);
    var reg=new RegExp('(,|^)'+id+'(,|$)');
    return (coo.search(reg) >= 0);
  });
  orz.set_post_zan=orz.set_zan_cookie('post_zan');
  orz.set_comment_zan=orz.set_zan_cookie('comment_zan');
  orz.has_post_zan=orz.has_zan_cookie('post_zan');
  orz.has_comment_zan=orz.has_zan_cookie('comment_zan');

})();

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name 站内评论相关函数功能
 * @Author lizus.com
 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */

(function($){
  /**
   * 评论发表时检测评论表单，如有错误则输出提示用户
   * @param  {[jQuery Object]} j  评论表单的jQuery对象
   * @param  {[string]} err [输出用的html文本]
   * @return
   */
  orz.echo_comment_error=function(j,err) {
    orz.show($(j).find('.error')).addClass('error_box').html(err);
    orz.log('评论提交出错：',err);
  };

  /**
   * 发表评论者的头像
   */
  orz.get_comment_avatar=function() {
    var user=orz.user();
    return user.avatar || 'http://image.uisdc.com/wp-content/uploads/2018/06/avatar-uisdc-chat.png';
  };

  /**
   * 获取表单项的值，如果有设置placeholder，则比较后再返回
   * @param  {[string]} name [表单项的name值]
   * @param  {[jQuery Object]} form [评论表单的jQuery对象]
   */
  orz.get_form_item_val=orz.curry(function (name,form){
    var item=$(form).find('[name='+name+']');
    var val=item.val();
    if (val == orz.attr('placeholder',item)) val='';
    return val;
  });
  //一行可用字符数
	orz.lineLen = function() {
		$('.lineLen').each(function () {
			var fsize=$(this).css('font-size');
			var w=$(this).width();
			orz.setAttr('line',2*w/parseInt(fsize),$(this));
		});
	};
  //通过输入的内容确定文本框的高度
  orz.setLine=function (ele){
    var s=$(ele).val();
		var lineLength=orz.attr('line',ele);
		var lineHeight=parseInt($(ele).css('line-height'));
		var needLine=1;//需要的行数
		var tempCount=0;//数数用，一行满了清零,遇到回车清零
		for (var i = 0; i < s.length; i++) {
			if(s.charCodeAt(i)==10) {
				tempCount=0;
				needLine++;
			}else{
				if (s.charCodeAt(i)>127) {
					tempCount+=2;
				}else{
					tempCount++;
				}
				if (tempCount>=lineLength) {
					needLine++;
					tempCount=0;
				}
			}
		}
		$(ele).height(needLine*lineHeight);
  };

  /**
   * 以下用于获取图片验证码，使用时使用orz.get_captcha即可，参数为需要放置验证码的元素context
   * 为确保获取，可添加元素的'get.captcha.fail'事件，事件内容为再获取一次，最多重试3次。
   */
  orz.get_captcha_img=function (code){
    return orz.replace(/image\./,'www.',uisdc.theme_url)+'/captcha/captcha.php?prefix='+code+'&nonce='+((new Date()).getTime());
  };
  orz.apply_captcha=orz.post(function (res){
    if (typeof res !='string' || res.length!=12) {
      var count=orz.attr('count',$(this)) || 0;
      if (count<3) {
        $(this).trigger('get.captcha.fail');
        count++;
        orz.setAttr('count',count,$(this));
      }
      return;
    }
    $(this).find('.captcha_img').attr('src',orz.get_captcha_img(res));
    $(this).find('[name=captcha_prefix]').val(res);
    $(this).removeClass('hidden');
    orz.init($(this));
  });
  orz.get_captcha=orz.apply_captcha({
    action:'get_captcha'
  });
})(jQuery);

(function($){
  //用于判断变量是否是jQuery对象
  orz.isjQuery=function (x) {
    return x instanceof jQuery;
  };
  //页面是否正在执行滚动脚本
  orz.isScrolling=function () {
    return $('body').hasClass('scrolling');
  };
  //页内滚动开始时执行
  orz.startScroll=function (j) {
    $('body').addClass('scrolling');
    if (orz.isjQuery(j)) {
      j.trigger('startScroll');
    }
  };
  //页面滚动结束时执行
  orz.endScroll=function (j) {
    $('body').removeClass('scrolling');
    if (orz.isjQuery(j)) {
      j.trigger('endScroll');
    }
  };
  orz.isUserLogin=function (){
    return orz.isNotEmpty(orz.user());
  };
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
优化页面滚动事件，在$(window).on('scroll')滚动事件中添加事件用orz.scroll包裹
示例:
(function($){
  var go=orz.scroll(function (e) {
    var st=window.pageYOffset
    			|| document.documentElement.scrollTop
    			|| document.body.scrollTop
    			|| 0;
    orz.log(st);
  });
  $(window).on('scroll',go);
})(jQuery);
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  orz.scroll=function (fn) {
    var scrolling=false;
    return function (e) {
      if (!scrolling) {
        window.requestAnimationFrame(function (e){
          fn.call(e);
          scrolling=false;
        });
        scrolling=true;
      }
    };
  };
})(jQuery);

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name 元素状态设定用
 * @Author lizus.com
 * status可选：
 * pending 标识功能处理中
 * done 标识功能处理完成
 * disable 标识功能不可用，通常用于禁止鼠标点击事件
 * init 标识是否初始化完成，有些元素需要通过JS来加载，并添加事件，标识完成可以省掉多次初始化
 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */

(function($){
  orz.pending=orz.setAttr('status','pending');
  orz.done=orz.setAttr('status','done');
  orz.disable=orz.setAttr('status','disable');
  orz.enable=orz.setAttr('status','enable');
  orz.init=orz.setAttr('init','done');
  orz.isPending=orz.attrEq('status','pending');
  orz.isDone=orz.attrEq('status','done');
  orz.isDisable=orz.attrEq('status','disable');
  orz.isInit=orz.attrEq('init','done');
  orz.hidden=orz.addClass('hidden');
  orz.show=orz.removeClass('hidden');
})(jQuery);

(function(){
  //用于判断浏览器
	orz.getDevice=function () {
		var u=window.navigator.userAgent;
		if (u.indexOf('micromessenger')!=-1) return '微信';
		if (u.indexOf('Android')!=-1) return 'Android';
		if (u.indexOf('iPad')!=-1) return 'iPad';
		if (u.indexOf('iPhone')!=-1) {
			if (screen.height==812) return 'iPhone X';
			return 'iPhone';
		}
		if (u.indexOf('Edge')!=-1) return 'Edge浏览器';
		if (u.indexOf('360SE')!=-1) return '360浏览器';
		if (u.indexOf('360EE')!=-1) return '360浏览器';
		if (u.indexOf('Maxthon')!=-1) return '傲游浏览器';
		if (u.indexOf('Tencent')!=-1) return 'QQ浏览器';
		if (u.indexOf('MetaSr')!=-1) return '搜狗浏览器';
		if (u.indexOf('Opera')!=-1) return 'Opera浏览器';
		if (u.indexOf('Firefox')!=-1) return 'Firefox浏览器';
		if (u.indexOf('Chrome')!=-1) return 'Chrome浏览器';
		if (u.indexOf('Safari')!=-1) return 'Safari浏览器';
		if (u.indexOf('MSIE')!=-1) return 'IE浏览器';
		if (u.indexOf('like Gecko')!=-1) {
			if (u.indexOf('OPR')!=-1) {
				return 'Opara浏览器';
			}
			return 'IE浏览器';
		}
	}
})();

(function($){
  orz.getDateDiff=function (time) {
    var now=new Date().toString();
    var second=orz.dateDiff('second',time,now);
    var day=Math.floor(second/(24*3600));
    var hour=Math.floor((second%(24*3600))/3600);
    var minute=Math.floor((second%3600)/60);
    if (day>30) return time;
    if (day>3) return orz.replace(/^\d{4}-*\s*/,'',time);
    if (day>0) return day+'天前';
    if (hour>0) return hour+'小时前';
    if (minute>0) return minute+'分钟前';
    return '刚刚发表';
  };
})(jQuery);

(function($){
  //用于评论内容拉取后处理换行及空格
  orz.content_filter=function (str) {
    var html='';
    for (var i = 0; i < str.length; i++) {
      if(str.charCodeAt(i)==10) {
        html+='<br>';
      //}else if(str.charCodeAt(i)==32){
        //html+='&nbsp;';
      }else{
        html+=str.charAt(i);
      }
    }
    html=html.replace(/\s\s/,'&nbsp;&nbsp;');
    html=html.replace('rel="nofollow"','rel="nofollow" target="_blank"');
    html=html.replace('<a "','<a target="_blank" ');
    return html;
  }
})(jQuery);

(function($){
  //将json格式的评论解析成html并返回
  //内容源于ajax获取的评论
  orz.decodejson_comments=function (json,is_new) {
    var str=orz.jsonDecode(json);
    var html='';
    for (var i = 0; i < str.length; i++) {
      var t=str[i];
      var approved=t.approved;
      html+='<div class="comment_item ';
      if(is_new) html+='animated flash ';
      if(t.parent>0) html+='child_item ';
      if(t.is_sticky == 1) html+='sticky ';
      html+='approved'+approved+'" id="'+t.id+'" data-author="'+t.author+'">';
      html+='<div class="avatar">';
      if (t.author_url) {
        html+='<a href="'+t.author_url+'" target="_blank">';
      }
      html+='<span>'+t.avatar+'</span>';
      if (t.author_url) {
        html+='</a>';
      }
      html+='</div>';
      html+='<div class="comment_body">';
      html+='<div class="comment_main">';
      html+='<h4>';
      if (t.author_url) {
        html+='<a href="'+t.author_url+'" target="_blank">';
      }
      html+=t.author;
      if (t.author_url) {
        html+='</a>';
      }
      if (approved<1) {
        html+='<em class="approved_em">您的评论正在等待审核~</em>';
      }
      if (t.current_author>0) {
        if (uisdc.post_type=='hunter') {
          html+='<em class="me">细节猎人</em>';
        }else if(t.is_editor) {
          html+='<em class="me">主编</em>';
        }else{
          html+='<em class="me">特邀作者</em>';
        }
      }
      if (t.parent>0) {
        //html+=' <span>回复</span> <a href="#'+t.parent+'" data-comment-parent="'+t.parent+'"></a>';
        html+=' <span>回复</span> '+t.parent_author;
      }
      if(t.is_sticky == 1) html+='<i class="sticky">置顶</i>';
      html+='</h4>';
      html+='<p>'+orz.content_filter(t.content)+'</p>';
      html+='</div>';//comment_main
      html+='<h5>';
      html+='<span>'+orz.getDateDiff(t.time)+'</span> ';
      if(t.device) html+='<span>来自 '+t.city+'</span> <span>'+t.device+'</span> ';
      html+='<span class="comment_reply" data-pid="'+t.id+'">回复</span> ';
      html+='<span class="comment_zan';
      if (t.zan>0) {
        html+=' comment_zans';
      }
      html+='" data-id="'+t.id+'"><em>'+(t.zan || '')+'</em> 点赞</span>';
      var user=orz.user();
      if (orz.isNotEmpty(user) && user.is=='editor' && t.parent <=0 ) {
        if (t.is_sticky == 1) {
          html+='<span class="sticky_btn has_sticky" data-cid="'+t.id+'">取消置顶</span>';
        }else{
          html+='<span class="sticky_btn no_sticky" data-cid="'+t.id+'">置顶</span>';
        }
      }
      html+='</h5>';
      html+='</div>';//comment_body
      html+='</div>';//comment_item
    }
    return html;
  };
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
评论置顶操作，editor权限才可以有,按钮在decodejsone_comments中插入
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  $(document).on('click','.comment-list .sticky_btn',function () {
    if (!orz.isEditor()) return;
    var id=$(this).attr('data-cid');
    var status='no_sticky';
    if (has_sticky($(this))) {
      status='has_sticky';
    }
    var data={
      action:'comment_sticky',
      status:status,
      commentId:id
    };
    $.post(uisdc.ajax_url,data,function (res) {
      res=orz.jsonDecode(res);
      if (orz.isEmpty(res)) return;
      var sticky=res.data.sticky;
      if (sticky == 1) {
        move_sticky($('#'+id));
      }else{
        remove_sticky($('#'+id));
      }
    });
  });
  function has_sticky(j){
    return j.hasClass('has_sticky');
  }
  function move_sticky(j){
    j.remove();
  }
  function remove_sticky(j){
    j.remove();
  }
})(jQuery);

(function($){
  //用于页面指定跳转至某个元素的位置
  orz.scrollTo=function (j,offset) {
    if (orz.isMobile()) return;
    if (orz.isScrolling()) return;
    if (!orz.isjQuery(j)) return;
    var t=j;
    if (t.length<1) return;
    var that=$(this);
    var diff=offset-0;
    var s=1000;//速度
    var st=document.documentElement.scrollTop || 0;
    var offset=t.offset();
    var l=offset.top;
    if (!isNaN(diff)) l=l+diff;
    var len=Math.abs(st-l);
    s=s*len/4000;
    orz.startScroll(that);
    $('html,body').animate({
      scrollTop:l
    },s,function (){
      orz.endScroll(that);
    });
    return false;
  };
})(jQuery);

(function(){
  orz._get=function $_GET(tag) {
    var _get=location.search;
    if (_get) {
      var reg=new RegExp(tag+'=([^&]*)','g');
      var m,n;
      do {
        m=reg.exec(_get);
        if (m) n=m;
      } while (m);
      if (orz.isArray(n)) {
        return n[1];
      }
    }
    return null;
  }
})();

(function(){
  //当前页地址，不含传参及page
  orz.currentPageUrl=function (){
    var url=window.location.protocol + "//" + window.location.hostname + (window.location.port ? ':' + window.location.port: '')+window.location.pathname;
    url=orz.replace(/\/page\/.*$/,'',url);
    return url;
  };

})();


//当前页带#链接auto scrollTo #
jQuery(function ($){
  function getID(j) {
    var href=j.attr('data-href');
    if (!href) {
      href=j.attr('href');
    }
		var rs=href.split('#');
		var lh=location.href;
		var lhrs=lh.split('#');
    if (rs[0] && rs[0]!=lhrs[0]) {
      return '';
    }
		return rs.pop();
  }
	$('body').on('click','.auto-scroll',function (){
    if (orz.isMobile()) return;
    if (orz.isScrolling()) return;
    var target=getID($(this));
    if (!target) return;
		var t=$('#'+target);
		if (t.length<1) return;
    var that=$(this);
    var diff=$(this).attr('data-offset')-0;
		var s=1000;//速度
		var st=document.documentElement.scrollTop || 0;
		var offset=t.offset();
		var l=offset.top;
    if (!isNaN(diff)) l=l+diff;
		var len=Math.abs(st-l);
		s=s*len/4000;
    orz.startScroll(that);
		$('html').animate({
			scrollTop:l
		},s,function (){
      orz.endScroll(that);
		});
		return false;
	});
});

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
用于页面uisdc的处理
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  orz.uisdc=function () {
    return uisdc || false;
  };
  orz.status=function () {
    if (orz.uisdc()) {
      return orz.uisdc().status || false;
    }
    return false;
  };
  orz.pageData=function () {
    if (orz.uisdc()) {
      return orz.uisdc().pageData || false;
    }
    return false;
  };
  orz.user=function () {
    if (orz.pageData()) {
      return orz.pageData().user || false;
    }
    return false;
  };
  orz.singular=function () {
    if (orz.status()) {
      return orz.status().postid || false;
    }
    return false;
  };
  orz.commentList=function () {
    if (orz.pageData()) {
      return orz.pageData().comment_list || false;
    }
    return false;
  };
  orz.commentCount=function () {
    if (orz.pageData()) {
      return orz.pageData().comment_count || false;
    }
    return false;
  };
  orz.isUserCenter=function () {
    if (orz.status()) {
      return orz.status().is_u_center || false;
    }
    return false;
  };
  //用户中心页面用户数据
  orz.userInfo=function () {
    if (orz.pageData()) {
      return orz.pageData().userInfo || false;
    }
    return false;
  };
  //用户收藏页的收藏数据显示
  orz.userFav=function () {
    if (orz.pageData()) {
      return orz.pageData().userFav || false;
    }
    return false;
  };
  //未登录用户评论输入框默认显示内容
  orz.userPlaceholder=function () {
    var placeholder='确定不填？';
    if (orz.pageData()) {
        return orz.pageData().placeholder || placeholder;
      }
      return placeholder;
  };
  orz.isEditor=function () {
    if (orz.user()) {
      return orz.user().is =='editor' || false;
    }
    return false;
  };
  orz.isAuthor=function () {
    if (orz.user()) {
      return orz.user().is =='author' || orz.user().is =='editor' || false;
    }
    return false;
  };
  orz.isHome=function () {
    if (orz.status()) {
      return orz.status().is_home == 1 || false;
    }
    return false;
  };

  //添加disabled的class名称则点击无效
  $(document).on('click','.disabled',function () {
    return false;
  });
})(jQuery);

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name 全局事件
 * @Author lizus.com
 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  $('body').on('click','[disable=true]',orz.of(false));
  $('body').on('click','[data-status=disable]',orz.of(false));
	$(window).on('resize',orz.lineLen);
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
用于生成页面的翻页
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  //上一页的地址
  function prev_url(baseurl,paged){
    paged--;
    if (paged<2) {
      return baseurl;
    }
    return url(baseurl,paged);
  }
  //当前页地址
  function url(baseurl,paged){
    if (paged==1) return baseurl;
    return baseurl+'/page/'+paged;
  }

  //用于生成页面内的翻页，三个参数分别为基础地址，总页数，当前页码
  orz.pageNav=function (baseurl,pages,paged) {
    if (pages<2) return;
    var pageNav=$('.pagenav');
    var html='<ul class="nav">';
    if (paged>1) {
      html+='<li class="fy"><a href="'+prev_url(baseurl,paged)+'"><span><i class="icon-left-open-big"></i>上一页</span></a></li>';
    }
    var cls='';
    for (var i = 1; i <= pages; i++) {
      if (i==paged) {
        cls='class="active disabled"';
      }else{
        cls='';
      }
      if ((i>1 || i<paged) && Math.abs(i-paged)>3) {
        html+='<li class="disabled"><a href="#" class="dotdot" title=""><span>...</span></a></li>';
      }else{
        html+='<li '+cls+'><a href="'+url(baseurl,i)+'"><span>'+i+'</span></a></li>';
      }
    }
    if (paged<pages) {
      paged++;
      html+='<li class="fy"><a href="'+url(baseurl,paged)+'"><span>下一页<i class="icon-right-open-big"></i></span></a></li>';
    }
    html+='</ul>';
    pageNav.html(html);
    pageNav.removeClass('hidden');
    $(document).trigger('pageNavInit');
  }
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
页面404部分输出
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  orz.part404=function () {
    return '<div class="div404"><img src="https://image.uisdc.com/wp-content/uploads/2018/12/uisdc-hunter-default-pic-new.png" alt="404" class="img404"></div>';
  };
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
用于在页面加载时，载入页面所需的ajax数据
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
jQuery(function ($){
  var needUpdate=true;//是否需要更新数据
  var u=uisdc || {};
  var data=u.status || {};
  data.action='page_load';
  var userData=orz.getCookie('userData');
  if (orz.isNotEmpty(userData)) {
    userData=orz.jsonDecode(userData);
    if (orz.isEmpty(u.pageData)) u.pageData={};
    u.pageData.user=userData;
    needUpdate=false;
  }
  if (data.postid>0) needUpdate=true;
  if (data.is_u_center) needUpdate=true;
  if (data.is_u_fav) needUpdate=true;
  if (data.is_dubao) needUpdate=true;
  if (orz._get('login') || orz._get('logout')) needUpdate=true;
  if (needUpdate) {
    $.post(u.ajax_url,data,function (res) {
      res=orz.jsonDecode(res);
      u.pageData=res.data;
      var ud=orz.jsonEncode(u.pageData.user);
      if (orz.isEmpty(ud)) {
        ud=orz.jsonDecode([]);
      }
      orz.setCookie('userData',ud,1);
      $(document).trigger('pageDataLoaded');
    });
  }else{
    setTimeout(function () {
      $(document).trigger('pageDataLoaded');
    },0);
  }
  //去掉loading
  $(document).on('pageDataLoaded',function () {
    $('.dataLoading').removeClass('dataLoading');
  });
});

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name 网站点赞组件
 * @Author lizus.com
 * @Updated 20190512
 * @Description
 网站中常规点赞功能，包括文章点赞和评论点赞。用户点赞时通过Ajax传递文章ID或评论ID，服务器接收处理后，返回新的点赞计数，更新点赞按钮中的点赞数据。
 点赞按钮使用data-component名称zan来进行识别，class名has_zan表示已赞，此时按钮失效（当前站内不允许减赞）
 data-pid表示文章ID
 data-cid表示评论ID
 二者填一个即可。
 在组件中，class名为zan_count的元素负责记录点赞数（非必须）
 *
 * @Example
 <span class="zan" data-component="zan" data-pid="<?php echo $pid; ?>"> <i class="icon-zan"></i> <em class="zan_count"></em>赞 </span>
 *
 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */

(function($){
  /**
   * 设置查询用的数据
   */
  var getData=function (ele){
    return {
      action:'zan',
      pid:orz.attr('pid',$(ele)),
      cid:orz.attr('cid',$(ele))
    };
  };
  var setZanCookie=function (ele){
    var pid=orz.attr('pid',$(ele));
    var cid=orz.attr('cid',$(ele));
    if (pid>0) {
      orz.set_post_zan(pid);
    }else if(cid>0){
      orz.set_comment_zan(cid);
    }
  };
  var zanPost=orz.post(function (res){
    var res=orz.jsonDecode(res);
    if (res) {
      var data=res.data;
      var zan=data.zan-0;
      if (zan>0) {
        $(this).find('.zan_count').html(zan);
        $(this).addClass('has_zan');
      }
    }
    orz.done(this);
  });
  var zanClick=orz.click(function () {
    if (orz.isPending(this)) return;
    var data=getData(this);
    var setZan=zanPost(data);
    orz.pending(this);
    if ($(this).hasClass('has_zan')) {
      orz.done(this);
      return;
    }
    setZan(this);
    setZanCookie(this);
  });
  zanClick('[data-component=zan]');
})(jQuery);

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name simpleUpSlide
 * @Author lizus.com
 * @Updated 20190727
 * @Description
 * 简单的向上滚动轮播
 *
 * @Example
 <div data-component="simpleUpSlide">
  <ul>
    <li></li>
  </ul>
 </div>
 *
 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */

(function($){
  $('[data-component=simpleUpSlide]').each(function (){
    var ul=$(this).children('ul');
    if (ul.length<1) return;
    var lis=ul.children('li');
    if (lis.length<1) return;
    var during=1000;
    var stop=3000;
    var step=lis.outerHeight();
    var count=0;
    function loop(){
      count++;
      if (count>=lis.length) count=0;
      ul.animate({
        top:0-count*step
      },during);
      lp=setTimeout(loop,stop);
    }
    var lp=setTimeout(loop,stop);
  });
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
评论用户处理，登录用户显示用户信息，未登录用户给出输入框
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  function display_nouce_input() {
    $('.form-user-item').each(function () {
      $(this).html('<label><span>姓名</span><div><input type="text" name="user" data-placeholder="'+orz.userPlaceholder()+'" class="txt" /></div></label>');
    });
    $('body').trigger('form.placeholder.ready');
    $('body').trigger('aside_init');
  }
  function display_login_input(user){
    $('.form-user-item').each(function () {
      $(this).html('<i class="avatar" style="background-image:url('+user.avatar+');"></i><strong>'+user.nickname+'</strong> 您好');
    });
    $('body').trigger('aside_init');
  }
  $(document).on('pageDataLoaded',function () {
    var user=orz.user();
    if (orz.isEmpty(user)) {
      display_nouce_input();
    }else{
      display_login_input(user);
    }
  });
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
用户中心头部

---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
jQuery(function ($){
  var u_header=$('#u-header');
  if (u_header.length<1) return;
  $(document).on('pageDataLoaded',function () {
    var userInfo=orz.userInfo();
    if (!userInfo) return;
    var html='<div class="wrap page-wrap">';
    html+='<div class="author-main">';
    html+='<div class="info">';
    html+='<div class="thumb-div">';
    html+='<span class="thumb" style="background-image:url('+userInfo.avatar+');"></span>';
    html+='</div>';//thumb-div
    html+='<div class="txts">';
    html+='<h2>'+userInfo.nickname+'</h2>';
    var company= (userInfo.company == '请填写你的公司' || orz.isEmpty(userInfo.company)) ? '' : userInfo.company+'&nbsp;&nbsp;';
    html+='<h4>'+company+userInfo.job ;
    if (userInfo.sina && userInfo.sina.length>0) {
    html+= '<a href="'+userInfo.sina+'" target="_blank"> <i class="icon-sina"></i> </a>';
    }
    html+='</h4>';
    html+='<p>'+userInfo.info+'</p>';
    html+='</div>';//txts
    html+='</div>';//info
    html+='<div class="total">';
    if (userInfo.is_author == 1) {
      html+='<span>文章 <strong>'+userInfo.count_article+'</strong></span>';
      html+='<em class="vline"></em>';
    }
    if (userInfo.is_author == 1) {
      html+='<span>细节 <strong>'+userInfo.count_hunter+'</strong></span>';
      html+='<em class="vline"></em>';
    }
    html+='<span id="userFavCount">收藏 <strong>'+userInfo.count_fav+'</strong></span>';
    html+='</div>';//info
    html+='</div>';//author-main
    html+='<div class="author-menus">';
    var cls='';
    if (userInfo.is_author == 1) {
      html+='<a class="'+currentClass('is_u_index')+'" href="'+href('article')+'">文章</a>';
    }
    if (userInfo.is_author == 1) {
      html+='<a class="'+currentClass('is_u_hunter')+'" href="'+href('hunter')+'">细节</a>';
    }
    html+='<a class="'+currentClass('is_u_fav')+'" href="'+href('fav')+'">收藏</a>';
    if (isCurrentUser()) {
      html+='<a class="'+currentClass('is_u_setting')+'" href="'+href('setting')+'">设置</a>';
    }
    html+='</div>';//author-menus
    html+='</div>';//page-wrap
    u_header.html(html);
    $(document).trigger('userCenterHeaderInit');
  });

  function currentClass(tag){
    var status=orz.status();
    if (!status) return '';
    if (status[tag] == 1) return 'current';
    return '';
  }

  //用于构造用户中心的菜单
  function href(tag){
    var userInfo=orz.userInfo();
    if (!userInfo) return '';
    var baseurl=userInfo.baseurl;
    //console.dir(baseurl.indexOf(baseurl.length-1));
    switch (tag) {
      case 'hunter':
        return baseurl+'?pt=hunter';
        break;
      case 'fav':
        return baseurl+'/fav';
        break;
      case 'setting':
        return baseurl+'/setting';
        break;
      default:
        return baseurl;
    }
  }

  function isCurrentUser(){
    var userInfo=orz.userInfo();
    var user=orz.user();
    if (userInfo && user) return userInfo.uid == user.uid;
    return false;
  }
});

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
用户设置页
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
jQuery(function ($){
  var u_setting=$('#u_setting');
  if (u_setting.length<1) return;
  $(document).on('pageDataLoaded',function () {
    var userInfo=orz.userInfo();
    if (orz.isEmpty(userInfo)) return;
    $('#u_job').html(userInfo.job);
    $('#u_company').html(userInfo.company);
    $('#u_info').html(userInfo.info);
  });
});

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
文章评论页第一个翻页自动载入
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
jQuery(function ($){
  $(document).on('pageDataLoaded',function () {
    if (orz.isEmpty(orz.singular())) return;
    var pageData=orz.pageData();
    if (orz.isEmpty(pageData)) return;
    var comment_count=pageData.comment_count;
    if (comment_count<20) return;
    var btn=$('#get_comments');
    var scrolled=true;
    $(window).on('scroll',autoGetComments);
    function autoGetComments() {
      if (scrolled) {
        scrolled=false;
        if (btn.hasClass('autoloading')) return;
        setTimeout(function () {
          if (btn.attr('data-paged') != 2) {
            $(window).off('scroll',autoGetComments);
            return;
          }
          var btnOffset=btn.offset();
          var st=window.pageYOffset
          			|| document.documentElement.scrollTop
          			|| document.body.scrollTop
          			|| 0;
          var ct=document.documentElement.clientHeight;
          if (st+ct>=btnOffset.top-200) {
            console.dir('me');
            btn.addClass('autoloading');
            btn.trigger('click');
          }
          scrolled=true;
        },50);
      }
    }
  });
});

(function($){
  function placeholder_init(j) {
    var val=orz.trim(j.val());
    var placeholder=orz.trim(j.attr('data-placeholder'));
    if (val == placeholder) val='';
    if (orz.isEmpty(val)) {
      j.val(placeholder);
      j.addClass('placeholder');
      j.addClass('txt_empty');
    } else {
      j.removeClass('placeholder');
      j.removeClass('txt_empty');
    }
  }
  $('body').on('form.placeholder.ready',function () {
    $('[data-placeholder]').each(function () {
      if (orz.isInit(this)) return;
      orz.init(this);
      placeholder_init($(this));
    });
  });
  $('body').on('focusin','[data-placeholder]',function () {
    var val=orz.trim($(this).val());
    var placeholder=orz.trim($(this).attr('data-placeholder'));
    if (val == placeholder) $(this).val('');
    $(this).removeClass('placeholder');
    $(this).removeClass('txt_empty');
  });
  $('body').on('focusout','[data-placeholder]',function () {
    placeholder_init($(this));
  });
  $('body').trigger('form.placeholder.ready');
})(jQuery);

jQuery(function ($){
  $('body').on('click','.bdEvent',function () {
    var c=$(this).attr('data-category') || 'advertisement';
    var a=$(this).attr('data-action') || 'click';
    var l=$(this).attr('data-label') || 'link';
    _hmt.push(['_trackEvent',c,a,l]);
  });
  $('body').on('click','.homepage_slide a',function () {
    var index=$('.homepage_slide a').index($(this));
    index++;
    var c=$(this).attr('data-category') || 'homepage_slide';
    var a=$(this).attr('data-action') || 'click';
    var l=$(this).attr('data-label') || 'slide_'+index;
    _hmt.push(['_trackEvent',c,a,l]);
  });
  $('#menu-primary .link-0').on('click',function () {
    var index=$('#menu-primary .link-0').index($(this));
    var num=index+1;
    _hmt.push(['_trackEvent','main-nav','click','nav'+num]);
  });
});

jQuery(function ($){
  var h=$('.home-first-screen');
  if (h.length<1) return;
  h.find('.item1 a').on('click',function () {
    var num=h.find('.item1 a').index($(this))+1;
    _hmt.push(['_trackEvent','首页首屏','轮播','轮播'+num]);
  });
  h.find('.item2 a').on('click',function () {
    var num=h.find('.item2 a').index($(this))+1;
    _hmt.push(['_trackEvent','首页首屏','四格图','图片'+num]);
  });
  h.find('.home-menus a').on('click',function () {
    var num=h.find('.home-menus a').index($(this))+1;
    _hmt.push(['_trackEvent','首页首屏','菜单','菜单'+num]);
  });
  h.find('.home-subjects a').on('click',function () {
    var num=h.find('.home-subjects a').index($(this))+1;
    _hmt.push(['_trackEvent','首页首屏','自定义一','链接'+num]);
  });
  h.find('.home-topics a').on('click',function () {
    var num=h.find('.home-topics a').index($(this))+1;
    _hmt.push(['_trackEvent','首页首屏','自定义二','链接'+num]);
  });
  h.find('.home-course a').on('click',function () {
    var num=h.find('.home-course a').index($(this))+1;
    _hmt.push(['_trackEvent','首页首屏','课程','课程'+num]);
  });
  h.find('.dubao a').on('click',function () {
    var num=h.find('.dubao a').index($(this))+1;
    _hmt.push(['_trackEvent','首页首屏','读报','链接'+num]);
  });
});

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
页面内的微信登录小弹窗
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  function get_str_from_code(str) {
    var arr=[];
    for(var i=0;i<str.length;i++){
      arr.push(String.fromCharCode(str[i]));
    }
    arr=arr.join('');
    arr=arr.replace(/\\\//g,'/');
    arr=arr.replace(/\\$/,'');
    return arr;
  }
  var wxlogin=$('#wxlogin');
  if (wxlogin.length<1) return;
  var protocol=wxlogin.find('.wxlogin-protocol label');
  if (protocol.length<1) return;
  var btn=wxlogin.find('.btn');
  if (btn.length<1) return;
  protocol.on('click',function (e) {
    if (!$(e.target).hasClass('link')) {
      e.stopPropagation();
      e.preventDefault();
      orz.log($(this));
      $(this).toggleClass('checked');
    }
  });
  btn.on('click',function () {
    if (protocol.hasClass('checked')) {
      return true;
    }
    alert('请先勾选遵守协议');
    return false;
  });
  wxlogin.on('modal.show',function () {
    var w=$('#wechatEwm');
    if (w.length<1) return;
    if (w.attr('src') == 'about:blank') {
      w.attr('src',get_str_from_code(uisdc.wechatEwm));
    }
  });
})(jQuery);

/* ---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=*
点赞相关JS
---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=* */

(function($){
  var zan='zan';
  //用于判断用户是不是已经赞过这条
  function has_zan(pid){
    var re=false;
    if(!pid || pid<=0) return;
    var coo=orz.trim(orz.getCookie(zan));
    var index=coo.search(pid);
    if (index>=0) re=true;
    return re;
  }

  //设置点赞,如果已点,就删,没点就添加
  function set_zan(pid) {
    var coo=orz.trim(orz.getCookie(zan));
    var index=coo.search(pid);
    if (index>=0) {
      coo=coo.substring(0,index)+coo.substring(index+pid.length+1);
    }else {
      coo=coo+','+pid;
    }
    coo=orz.trim(coo);
    coo=coo.replace(/^,|,$/,'');
    orz.setCookie(zan,coo,365);
  }

  window.set_zan=set_zan;
  window.has_zan=has_zan;
})(jQuery);

/* ---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=*
倒计时 eg:
<div class="djs-widget">
<div class="djs" data-date="2018-07-18 12:30:00">
<span><i class="day">19</i> 天</span>
<span><i class="hour">18</i> 时</span>
<span><i class="minute">30</i> 分</span>
<span><i class="second">30</i> 秒</span>
</div>
</div>
---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=* */

(function($){
  var num2=orz.lpad(0,2);
  function djs() {
    $('.djs-widget').each(function () {
      var targetTime=$(this).find('.djs').attr('data-date');
      if (!orz.isExist(targetTime)) return;
      var day=$(this).find('.day');
      var hour=$(this).find('.hour');
      var minute=$(this).find('.minute');
      var second=$(this).find('.second');
      var that=$(this);
      function loop() {
        var now=new Date().toString();
        var diff=orz.dateDiff('second',now,targetTime);
        if (diff<=0) {
          that.addClass('hidden');
          return;
        }
        var dayTime=Math.floor(diff/(24*3600));
        var hourTime=Math.floor((diff%(24*3600))/3600);
        var minuteTime=Math.floor((diff%3600)/60);
        var secondTime=Math.floor(diff%60);
        day.html(num2(dayTime));
        hour.html(num2(hourTime));
        minute.html(num2(minuteTime));
        second.html(num2(secondTime));
        if (dayTime<1) {
          day.parent().addClass('hidden');
          second.parent().removeClass('hidden');
        }
        setTimeout(loop,1000);
      }
      $(this).removeClass('hidden');
      loop();
    });
  }
  djs();
  $('body').on('djs.reload',djs);
})(jQuery);


(function($){
	function comment_list_init() {
		var a=$('#commentlist');
		if(a.length<1) return;
		a.find('[data-comment-parent]').each(function () {
			$(this).html($('#'+$(this).attr('data-comment-parent')).attr('data-author'));
		});
		$('.comment_zan').each(function () {
      var id=$(this).attr('data-id');
      if (has_comment_zan(id)) {
        $(this).addClass('has_zan');
      }
    });
		$('body').trigger('aside_init');
	}
	function go_comment_top() {
		var t=$('#comment_form');
		if(t.length<1) return;
		var s=1000;//速度
		var st=window.pageYOffset
		|| document.documentElement.scrollTop
		|| document.body.scrollTop
		|| 0;
		var l=0;
		var offset=t.offset();
		l=offset.top;
		var len=Math.abs(st-l);
		s=s*len/4000;
		$('body').addClass('scrolling');
		$('html,body').animate({
			scrollTop:l
		},s,function (){
			$('body').removeClass('scrolling');
		});
	}
	window.comment_list_init=comment_list_init;
	window.go_comment_top=go_comment_top;
})(jQuery);

(function($){
	$('body').on('click','.comment_reply',function () {
		var p=$(this).parent().parent();
		var form=p.find('.comment-form');
		$('.comment-form').addClass('hidden');
		if (form.length<1) {
			var f=$('#comment_form');
			if(f.length<1) return;
			var id=$(this).attr('data-pid')-0;
			if(id<0) return;
			f.clone(true).insertAfter($(this).parent());
			form=p.find('.comment-form');
			form.attr('id','');
			form.find('[name=parent]').val($(this).attr('data-pid'));
			form.prepend('<h3 class="comment_reply_h3">回复评论 <span class="close">取消回复</span></h3>');
			if (!orz.isUserLogin()) {
				get_captcha(form.find('.captcha-div'));
			}
		}
		form.removeClass('hidden');
		$('#si_image_log').trigger('click');
		$('body').trigger('aside_init');
	});
})(jQuery);

(function($){
	$('body').on('click','.comment_reply_h3 .close',function () {
		$('.comment-form').addClass('hidden');
		$('#comment_form').removeClass('hidden');
		go_comment_top();
	});
})(jQuery);

//留言框检查
(function($){
	var t=$('.textarea_need');
	if(t.length<1) return;
	//获取文本真实的字符数
	function getRealLen(str) {
		if (str == null) return 0;
    if (typeof str != "string"){
        str += "";
    }
    return str.replace(/[^\x00-\xff]/g,"01").length;
	}
	//一行可用字符数
	function lineLen() {
		t.each(function () {
			var fsize=$(this).css('font-size');
			var w=$(this).width();
			$(this).attr('data-line',2*w/parseInt(fsize));
		});
	}
	lineLen();
	$(window).on('resize',lineLen);
	$('body').on('keyup','.textarea_need',function () {
		var s=$(this).val();
		var lineLength=$(this).attr('data-line');
		var needLine=1;//需要的行数
		var tempCount=0;//数数用，一行满了清零,遇到回车清零
		for (var i = 0; i < s.length; i++) {
			if(s.charCodeAt(i)==10) {
				tempCount=0;
				needLine++;
			}else{
				if (s.charCodeAt(i)>127) {
					tempCount+=2;
				}else{
					tempCount++;
				}
				if (tempCount>=lineLength) {
					needLine++;
					tempCount=0;
				}
			}
		}
		$(this).height(needLine*25);
		$(this).val($(this).val().substring(0,800));
		var total=800;//总字数
		$(this).siblings('.total_count').find('.count').html(total-$(this).val().length);
	});
	$('body').on('focusin','.textarea_need',function () {
		var total=800;//总字数
    var val=orz.trim($(this).val());
    var placeholder=orz.trim($(this).attr('data-placeholder'));
    if (val == placeholder) $(this).val('');
		$(this).siblings('.total_count').removeClass('hidden');
		$(this).siblings('.total_count').find('.count').html(total-$(this).val().length);
	});
	$('body').on('focusout','.textarea_need',function () {
		$(this).siblings('.total_count').addClass('hidden');
	});
})(jQuery);

(function($){
	$('.comment-form .txt').on('focusin',function () {
		$(".error").html('').removeClass('error_box');
	});
	$('[name=comment]').on('focusin',function () {
		var d=$(this).parents('.form-item').siblings('.yzm-div');
		if (d.hasClass('hidden') && !orz.isUserLogin()) {
			d.removeClass('hidden');
			get_captcha(d);
			$('body').trigger('aside_init');
		}
	});
})(jQuery);

(function($){
	$('body').on('comment.list.change',function () {
    comment_list_init();
    $('.comment-words').trigger('comment.words.init');
	});
	$('body').on('comment.list.change',function () {
		var c=$('#commentlist');
		if (c.length<1) return;
		var ch=c.children('.comment_item');
		if (ch.length<1) {
			c.addClass('commentlist_empty');
		}else{
			c.removeClass('commentlist_empty');
		}
	});
})(jQuery);

(function($){
	$('.comment-words').on('comment.words.init',function () {
		var comments=$('#commentlist .comment_item');
		var html=$(this).html();
		if (comments.length>3) {
			$(this).children('.less').addClass('hidden');
			$(this).children('.more').removeClass('hidden');
		}
	});
	$('.comment-words').find('.btn').on('endScroll',function () {
		$('.comment-form .textarea').addClass('textarea_animate');
		setTimeout(function () {
			$('.comment-form .textarea').removeClass('textarea_animate');
		},1000);
	});
})(jQuery);

/* ---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=*
网站默认评论模块显示评论数
---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=* */
jQuery(function ($){

  var t=$('.uisdc-comments');
  if (t.length<1) return;

  $(document).on('pageDataLoaded',function () {
    var res=orz.commentCount()-0;
    var html='';
    if (orz.sm() && orz.isEmpty(orz.user())) {
      html='<span class="small-login-wx">点击 <span class="modal-open" data-modal-id="wxlogin">登录</span> 微信，亮头像秀观点。</span>';
    }
    if (res>0) {
      html=html.replace('。','，');
      html+='已发布 <em>'+res+'</em> 条';
    }else if(!html){
      if (uisdc.post_type=='hunter') {
        html='支持或反对猎人观点请下方留言';
      }else{
        html='文章分享不易 欢迎评论鼓励';
      }
    }
    t.find('.comment-part-title small').html(html);
  });
});

/* ---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=*
点赞相关JS
---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=* */

(function($){
  var zan='comment_zan';
  //用于判断用户是不是已经赞过这条
  function has_zan(pid){
    var re=false;
    if(!pid || pid<=0) return;
    var coo=orz.trim(orz.getCookie(zan));
    var index=coo.search(pid);
    if (index>=0) re=true;
    return re;
  }

  //设置点赞,如果已点,就删,没点就添加
  function set_zan(pid) {
    var coo=orz.trim(orz.getCookie(zan));
    var index=coo.search(pid);
    if (index>=0) {
      coo=coo.substring(0,index)+coo.substring(index+pid.length+1);
    }else {
      coo=coo+','+pid;
    }
    coo=orz.trim(coo);
    coo=coo.replace(/^,|,$/,'');
    orz.setCookie(zan,coo,365);
  }
  window.set_comment_zan=set_zan;
  window.has_comment_zan=has_zan;
})(jQuery);

jQuery(function ($){
  var form_content='';
  var echo_error=orz.echo_comment_error;
  $('.comment_post').on('submit',function (){
    var that=$(this);
    var user=that.find('[name=user]').val();
    var content=orz.trim(that.find('[name=comment]').val());
    var captcha_code=that.find('[name=captcha_code]').val();
    var captcha_prefix=that.find('[name=captcha_prefix]').val();
    if (content==that.find('[name=comment]').attr('data-placeholder')) content='';
    if (captcha_code==that.find('[name=captcha_code]').attr('data-placeholder')) captcha_code='';
    if (user==null || user==that.find('[name=user]').attr('data-placeholder')) {
      user='匿名用户';
    }
    //读取当前登录用户信息，如果未登录则为空数组
    var currentUser=orz.user();
    if(orz.isEmpty(currentUser)){
      if (!captcha_code) {
        echo_error(that,'请填写验证码');
        return false;
      }
    }
    if (!content) {
      echo_error(that,'请填写评论内容');
      return  false;
    }
    if (content == form_content) {
      echo_error(that,'您的评论重复了，请重新输入。');
      return  false;
    }
    var parent=that.find('[name=parent]').val()-0;
    content=orz.trim(content);
    orz.disable(that.find('[name=submit]')).html('评论提交中...');
    var data={
      action:'post_comment',
      pid:uisdc.status.postid,
      user:user,
      comment:content,
      parent:parent,
      captcha_code:captcha_code,
      captcha_prefix:captcha_prefix,
      device:orz.getDevice()
    };
    if (returnCitySN) {
      data['city']=returnCitySN['cname'];
    }
    $.post(uisdc.ajax_url,data,function (res) {
      orz.enable(that.find('[name=submit]')).html('提交评论');
      var s=orz.jsonDecode(res);
      if (s) {
        if (s.error) {
          that.find('.error').addClass('error_box').html(s.error);
        }else{
          that.find('.error').removeClass('error_box').html('');
          that.find('.captcha-img').trigger('click');
          var str=orz.decodejson_comments(res,true);
          var list=$('#commentlist');
          var parentID=s[0].parent;
          if (parentID>0) {
            list.find('#'+parentID).after(str);
          }else{
            list.prepend(str);
          }
          $('body').trigger('comment.list.change');
          that.find('[name=comment]').val('');
          that.find('[name=captcha_code]').val('');
          form_content=content;
          $('.comment-form').addClass('hidden');
          $('#comment_form').removeClass('hidden');
          go_comment_top();
        }
      }else{
        echo_error(that,res);
      }
      $('body').trigger('aside_init');
      $('.comment-words').trigger('comment.words.init');
    });
    return false;
  });
});

jQuery(function ($){
  var list=$('#commentlist');
  var btn=$('#get_comments');
  var tip=$('#comment_loading');
  if (list.length<1) return;
  $(document).on('pageDataLoaded',function () {
    var res=orz.commentList();
    orz.log(res);
    var str='';
    var paged=btn.attr('data-paged')-0;
    if (res) {
      str=orz.decodejson_comments(orz.jsonEncode(res));
      paged++;
      if (res.length>=20) {
        btn.attr('data-paged',paged);
        btn.removeClass('hidden');
      }
    }
    tip.addClass('hidden');
    list.append(str);
    $('body').trigger('comment.list.change');
  });

  $('#get_comments').on('click',function (){
    var that=$(this);
    var tip=$('#comment_loading');
    that.addClass('hidden');
    tip.removeClass('hidden');
    var paged=that.attr('data-paged')-0;
    var data={
      action:'comment_list',
      pid:orz.singular(),
      paged:paged,
    };
    var st=window.pageYOffset
    			|| document.documentElement.scrollTop
    			|| document.body.scrollTop
    			|| 0;
    $.post(uisdc.ajax_url,data,function (res) {
      var s=orz.jsonDecode(res);
      var str=orz.decodejson_comments(res);
      tip.addClass('hidden');
      if (str) {
        var list=$('#commentlist');
        var btn=$('#get_comments');
        var paged=btn.attr('data-paged')-0;
        paged++;
        btn.attr('data-paged',paged);
        if (s.length>=20) {
          btn.removeClass('hidden');
        }
        var items=list.children('.comment_item');
        list.append(str);
        $('body').trigger('comment.list.change');
        if (btn.hasClass('autoloading')) {
          btn.removeClass('autoloading');
        }else{
          $('html,body').animate({
            scrollTop:st
          },0);
        }
      }
    });
    return false;
  });
});

//顶部导航下拉菜单
(function($){
  var a=$('.topmenu-dropdown');
  if(a.length<1) return;
  var menus=a.find('.dropdown-item a');
  var id=0;//用于延迟获取数据
  /*
  menus.on('mouseenter',function () {
    var that=$(this);
    if(id>0) clearTimeout(id);
    id=setTimeout(function () {
      menus.removeClass('hover');
      that.addClass('hover');
      var data={
        action:'get_topmenu_posts',
        str: that.attr('data-id')
      };
      $.post(uisdc.ajax_url,data,function (res) {
        res=orz.jsonDecode(res);
        if (res.data && orz.isArray(res.data)) {
          $('#topmenu-posts').html(res.data.join());
        }
      });
    },500);
  });
  menus.on('mouseleave',function () {
    if(id>0) clearTimeout(id);
  });
  */
  $('body').on('mouseenter',function (e) {
    if (!a.hasClass('hidden')) {
      var $t=$(e.target);
      if ($t.hasClass('menu-container') || $t.parents('.menu-container').length>0 || $t.hasClass('topmenu-dropdown') || $t.parents('.topmenu-dropdown').length>0) {

      }else{
        a.addClass('hidden');
      }
    }
  });
  a.on('mouseleave',function () {
    a.addClass('hidden');
  });
  $('#header a').on('hover',function () {
    var that=$(this);
    if (that.attr('data-target')=='allposts-dropdown') {
      $('.allposts-dropdown').removeClass('hidden');
    }else{
      $('.allposts-dropdown').addClass('hidden');
    }
  });

})(jQuery);

jQuery(function ($){
  var scrolling=false;
  header_bg_scrolling();
  scrollEvent();
  $(window).on('resize',header_bg_scrolling);
  function header_bg_scrolling(){
    if (orz.md()) {
      scrolling=false;
      $(window).on('scroll',scrollEvent);
    }else{
      $(window).off('scroll',scrollEvent);
    }
  }
  function scrollEvent(){
    var st=window.pageYOffset
    || document.documentElement.scrollTop
    || document.body.scrollTop
    || 0;
    if (st>0) {
      if (!scrolling) {
        $('#header-bg').addClass('scrolling');
        scrolling=true;
      }
    }else{
      if (scrolling) {
        $('#header-bg').removeClass('scrolling');
        scrolling=false;
      }
    }
  }
});

/* ---=*--*=*-=*-=-*-=*  *---=*--*=*-=*-=-*-=*
头部用户登录后显示
---=*--*=*-=*-=-*-=*  *---=*--*=*-=*-=-*-=* */
jQuery(function ($){
  var t=$('#loginPanel');
  if (t.length<1) return;

  $(document).on('pageDataLoaded',function () {
    var html='<ul><li class="has-children logLi">';
    var user=orz.user();
    if (orz.isEmpty(user)) {
      html+='<span title="点击登录" class="avatar modal-open" data-modal-id="wxlogin"><img src="//image.uisdc.com/wp-content/uploads/2018/06/avatar-uisdc-chat.png" alt="avatar"></span>';
    }else{
      var menus=user.menus;
      html+='<a class="avatar" href="'+menus[0].href+'" target="_blank">';
      html+='<img src="'+user.avatar+'" alt="avatar">';
      html+='</a>';
      html+='<ul class="sub-nav">';
      html+='<li><span><em>'+user.nickname+'</em></span></li>';
      var cls='';
      for (var i = 0; i < menus.length; i++) {
        if (i==menus.length-1) {
          cls=' class="borderTop logout"';
        }else{
          cls='';
        }
        html+='<li'+cls+'><a href="'+menus[i].href+'">'+menus[i].title+'</a></li>';
      }
      html+='</ul>';//sub-nav
    }
    html+='</li></ul>';
    t.html(html);
    $(document).trigger('loginPanelReady');
  });

  //更换注销跳转链接到当前页
  $(document).on('loginPanelReady',function () {
    var logout=$('.logout a');
    if (logout.length<1) return;
    logout.each(function () {
      var href=$(this).attr('href');
      href=href.replace(/redirect_to=([^&]+)/,'redirect_to='+encodeURIComponent(uisdc.current_page_url)+'%3Flogout%3Dtrue');
      $(this).attr('href',href);
    });
  });
});

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
读报点赞
z: data-name+_+data-id
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  var zan='dubao_zan';//读报点赞的名称
  //获取用户点赞的cookie
  function get_zan_cookie() {
    return orz.trim(orz.getCookie(zan));
  }

  //读报项点赞判断用值
  function get_z(j) {
    if(!orz.isjQuery(j)) return '';
    return j.attr('data-name')+'_'+j.attr('data-id');
  }

  //判断用户的cookie中对当前的读报项是否已点赞，用页面初始化时使用
  function has_zan_cookie(z){
    var re=false;
    if(!z) return;
    var coo=get_zan_cookie();
    var index=coo.search(z);
    if (index>=0) re=true;
    return re;
  }

  //用于判断当前读报是否已点赞
  function has_zan(j){
    return j.hasClass('has_zan');
  }

  //设置点赞,如果已点,就删,没点就添加
  function set_zan(z) {
    var coo=get_zan_cookie();
    var index=coo.search(z);
    if (index>=0) {
      coo=coo.substring(0,index)+coo.substring(index+z.length+1);
    }else {
      coo=coo+','+z;
    }
    coo=orz.trim(coo);
    coo=coo.replace(/^,|,$/,'');
    orz.setCookie(zan,coo,365);
  }

  //设置元素的已点赞状态，并在PC端添加动画
  function has_zan_init(j){
    if(!orz.isjQuery(j)) return;
    j.addClass('has_zan');
    if (!orz.isMobile()) {
      j.addClass('animated');
      j.addClass('flash');
    }
  }

  function dubao_init(j){
    if(!orz.isjQuery(j)) return;
    var $zan=j.find('.zan');
    if($zan.length<1) return;
    $zan.each(function () {
      if(has_zan_cookie(get_z($(this)))) {
        has_zan_init($(this));
        $(this).children('em').html($(this).children('em').html()-0+1);
      }
      $(this).removeClass('hidden');
    });
    $zan.on('click',function () {
      var z=get_z($(this));
      if (!has_zan($(this))) {
        ajax_zan($(this));
      }
      return false;
    });
  }

  function ajax_zan(j){
    if(!orz.isjQuery(j)) return;
    var z=get_z(j);
    var data={
      action:'dubao_zan',
      'data-id':j.attr('data-id'),
      'data-name':j.attr('data-name')
    };
    var em=j.children('em');
    em.html(em.html()-0+1);
    has_zan_init(j);
    $.post(uisdc.ajax_url,data,function (res) {
      res=orz.jsonDecode(res);
      set_zan(z);
    });
  }

  function ajax_get_zan(j){
    if(!orz.isjQuery(j)) return;
    var $zan=j.find('.zan');
    if($zan.length<1) return;
    var i=0;
    $zan.each(function () {
        return;
      var that=$(this);
      var data={
        action:'dubao_zan_get',
        'data-id':$(this).attr('data-id'),
        'data-name':$(this).attr('data-name')
      };
      $.post(uisdc.ajax_url,data,function (res) {
        res=orz.jsonDecode(res);
        res=res['data'];
        that.children('em').html(res.join(''));
      });
    });
  }

  jQuery(function ($){
    var $z=$('.newspaper-content');
    if($z.length<1) return;
    dubao_init($z);
    var $items=$z.find('.newspaper-page');
    if($items.length<1) return;
    $items.each(function () {
      //ajax_get_zan($(this));
    });
  });
  window.dubao_init=dubao_init;
  //window.ajax_get_dubao=ajax_get_zan;
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
移动端顶部下拉菜单
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
	mobile_menu_init();
	$(window).on('resize',mobile_menu_init);
	function mobile_menu_init() {
		var cl=document.documentElement.clientWidth;
		if (cl>=768) return;
		var mobile_menu=$('#mobile_menu');
		if (mobile_menu.length>0) return;
		/*
		var lis=$('#menu-secondary .item-0');
		if (lis.length<1) {
			lis=$('.single-top-menu .item-0');
		}
		*/
		var html=$('<div id="mobile_menu"></div>');
		//var ul=$('<ul class="mobile_sub_menu_2"></ul>');
		var ul=$('.t-menus');
		var p='<div class="word">优设网是国内极具人气的设计平台 <br> 2012年成立至今，一直专注于设计师的学习成长交流。</div>';
		var search=$('.search-form').eq(0).clone();
		/*
		lis.each(function () {
			var m=$(this).clone();
			ul.append(m);
		});
		*/
		var primary=$('#menu-primary').clone();
		primary.attr('class','mobile_sub_menu_1');
		primary.attr('id','');
		html.append(primary);
		html.append(p);
		if(ul.length>0) html.append('<div class="t-menus">'+ul.html()+'</div>');
		html.append(search);
		$('body').append(html);
		$('body').append($('<div class="mobile_mark"></div>'));
		$('.menu-toggle').on('click',function (e) {
			if ($(this).hasClass('show-menu')) {
				$(this).removeClass('show-menu');
				$('#mobile_menu').trigger('menu.hidden');
			}else{
				$(this).addClass('show-menu');
				$('#mobile_menu').trigger('menu.show');
			}
			$('body').one('click',function () {
				$('#mobile_menu').trigger('menu.hidden');
				$('.menu-toggle').removeClass('show-menu');
			});
			e.stopPropagation();
		});
		$('#mobile_menu').on('menu.show',function () {
			$(this).addClass('menu-show');
			$('.mobile_mark').addClass('show-mark');
		});
		$('#mobile_menu').on('menu.hidden',function () {
			$(this).removeClass('menu-show');
			$('.mobile_mark').removeClass('show-mark');
		});
		$('#mobile_menu').on('click',function (e) {
			e.stopPropagation();
		});
		$('.mobile_mark').on('click',function () {
			$('#mobile_menu').trigger('menu.hidden');
		});
		/*
		$('.mobile_sub_menu_2>.has-children>a').on('click',function () {
			var s=$('.mobile_sub_menu_2>.has-children');
			var p=$(this).parent();
			if (p.hasClass('show-ul')) {
				p.removeClass('show-ul');
			}else {
				s.removeClass('current');
				s.removeClass('show-ul');
				p.addClass('show-ul');
			}
			return false;
		});
		*/
	}
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
用户中心
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */

(function($){
  $('.can_edit').on('click',function () {
    if ($(this).hasClass('editing')) return;
    var span=$(this).children('span');
    var html=orz.trim(span.text());
    var that=$(this);
    var type=that.attr('data-type');//输入框类型
    var count=that.attr('data-count');//限制字数
    html=orz.trim(html.replace('(待审)',''));
    var wordLess=count-html.length;//剩余字数
    $(this).addClass('editing');
    span.addClass('input');
    $('.box-warning').remove();
    switch (type) {
      case 'textarea':
        span.html('<textarea class="edit_input" style="height:'+(Math.ceil(count/40)*1.5+3)+'em;" name="'+$(this).attr('data-target')+'"> '+html+'</textarea><span class="wordCanInput">还可以输入<em>'+wordLess+'</em>字</span>');
        break;
      default:
      span.html('<input class="edit_input" name="'+$(this).attr('data-target')+'" value="'+html+'" /><span class="wordCanInput">还可以输入<em>'+wordLess+'</em>字</span>');
    }
    var a=$(this).find('.edit_input');
    //a.trigger('select').focus();
    var val=orz.trim(a.val());
    a.val('').focus().val(val);
    var w=$(this).find('.wordCanInput em');
    a.on('keyup',function () {
      var val=a.val();
      if (val.length>count) {
        val=val.substring(0,count);
        a.val(val);
      }
      wordLess=count-val.length;
      w.html(wordLess);
    });
    a.on('focusout',function () {
      var val=orz.trim(a.val());
      that.removeClass('editing');
      span.removeClass('input');
      if (val!=html) {
        that.addClass('dataing');
        span.addClass('loading');
        span.html('<i class="icon-spin1 animate-spin"></i>');
        var data={
          action:'edit_user_field',
          uid:that.attr('data-uid'),
          field:that.attr('data-target'),
          value:val
        };
        $.post(uisdc.ajax_url,data,function (res) {
          that.removeClass('dataing');
          span.removeClass('loading');
          res=orz.jsonDecode(res);
          span.html(res.data);
        });
      }else{
        span.html(html);
      }
    });
  });
})(jQuery);

//用于点击资料审核驳回的知道按钮
(function($){
  $('button.check_span').on('click',function () {
    var that=$(this);
    var data={
      action:'user_check_warning',
      uid:that.attr('data-uid')
    };
    $.post(uisdc.ajax_url,data,function (res) {
      res=orz.jsonDecode(res);
      if (res.data=='done') {
        that.parent().remove();
      }
    });
  });
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
用户收藏相关
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
//钩子为vitara-fav的class
jQuery(function ($){
  var btn=$('.vitara-fav');
  if (btn.length<1) return;
  $(document).on('pageDataLoaded',function () {
    if (!orz.singular()) return;//仅适用于单页
    var user=orz.user();
    //if (!user) return;
    if(orz.isEmpty(user)) {
      btn.attr('data-modal-id','wxlogin');
      btn.addClass('modal-open');
    }
    if (user.hasFav) {
      btn.addClass('has_fav');
      btn.each(function () {
        $(this).html('<i class="icon-check"></i> 已收藏');
      });
    }
    btn.removeClass('hidden');
  });
  //收藏按钮点击事件
  btn.on('click',function () {
    var that=$(this);
    if (that.hasClass('disabled')) return;
    var data={
      action:'addPostFav',
      pid:that.attr('data-pid'),
      hasFav: that.hasClass('has_fav')
    };
    var user=orz.user();
    //未登录用户
    if(orz.isEmpty(user)) {
      //that.siblings('.notLogin').removeClass('hidden');
      return true;
    }
    that.addClass('disabled');
    $.post(uisdc.ajax_url,data,function (res) {
      res=orz.jsonDecode(res);
      if (res.data) {
        if (that.hasClass('has_fav')) {
          setDefaultFav(btn);
        }else{
          setHasFav(btn);
        }
      }
      that.removeClass('disabled');
    });
  });

  function setHasFav(j){
    j.addClass('has_fav');
    j.html('<i class="icon-check"></i> 已收藏');
  }
  function setDefaultFav(j){
    j.removeClass('has_fav');
    j.html('<i class="icon-heart-border"></i> 收藏');
  }
});

//用户收藏页初始化及是否要显示移除收藏按钮
jQuery(function ($){
  //单个收藏文章显示
  function fav_item(obj){
    return '<li class="tuwen_item"><div class="tuwen_item_cont" data-pid="'+obj.id+'"><a class="thumbnail" href="'+obj.href+'" style="background-image:url('+obj.thumb+');" target="_blank"></a><h3><a href="'+obj.href+'" target="_blank">'+obj.title+'</a></h3><div class="post-metas"><span>'+obj.date+'</span><span class="hidden-xs"><a href="'+obj.cat_link+'">'+obj.cat_name+'</a></span></div></div></li>';
  }

  //用户收藏数减1
  function reduce_user_fav(){
    var userFav=orz.userFav();
    if (!userFav) return;
    var count=userFav.count || 0;
    count--;
    if (count<=0) count=0;
    userFav.count=count;
  }

  $(document).on('pageDataLoaded',function () {
    var userFav=orz.userFav();
    var list=$('#userFav');
    if (list<1) return;
    if (orz.isEmpty(userFav)) {
      list.parent().html(orz.part404());
      return;
    }
    var data=userFav.data;
    var html='';
    if (userFav.count>30) {
      html+='<li class="moreThen30">收藏文章超过 <strong>30</strong> 篇啦！请记得抽时间看完吧~</li>';
    }
    for (var i = 0; i < data.length; i++) {
      html+=fav_item(data[i]);
    }
    list.html(html);
    $(document).trigger('userFavInit');
    $(document).trigger('userFavCountUpdate');
  });

  //收藏显示完之后判断是否登录用户和当前页是同一用户需要显示移除按钮
  $(document).on('userFavInit',function () {
    var user=orz.user();
    if (!user) return;
    var current_uid=user.uid;
    var uid=orz.userFav().uid;
    var list=$('#userFav');
    if (list<1) return;
    var items=list.find('.tuwen_item_cont');
    if (current_uid==uid) {
      items.each(function () {
        var pid=$(this).attr('data-pid');
        $(this).append('<span class="remove-fav-btn" data-pid="'+pid+'" data-uid="'+uid+'">已看完<em>移除</em></span>');
      });
    }
  });

  //生成收藏页底部的翻页导航
  $(document).on('userFavInit',function () {
    var userFav=orz.userFav();
    if (!userFav) return;
    orz.pageNav(userFav.baseurl,userFav.pages,userFav.paged);
  });

  //显示收藏数
  $(document).on('userFavCountUpdate',function () {
    var userFav=orz.userFav();
    if (!userFav) return;
    var totalNum=$('#userFavCount');
    totalNum.children('strong').html(userFav.count);
    totalNum.removeClass('hidden');
  });

  $('body').on('click','.remove-fav-btn',function () {
    var that=$(this);
    var data={
      action:'user_fav_remove',
      pid:$(this).attr('data-pid'),
      uid:$(this).attr('data-uid')
    };
    $.post(uisdc.ajax_url,data,function (res) {
      res=orz.jsonDecode(res);
      if (res.data) {
        that.parents('.tuwen_item').remove();
        reduce_user_fav();
        $(document).trigger('userFavCountUpdate');
      }
    });
  });
});

//文章页需要登录后才能使用收藏功能
jQuery(function ($){
  $('.notLogin a').attr('target','_top');
  $('.notLogin .cancel').on('click',function () {
    $('.notLogin').addClass('hidden');
  });
  $(document).on('click',function (e) {
    if (!$(e.target).hasClass('notLogin') && $(e.target).parents('.notLogin').length<1 && !$(e.target).hasClass('vitara-fav')  && $(e.target).parents('.vitara-fav').length<1) {
      $('.notLogin').addClass('hidden');
    }
  });
});

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
详情文章页生成自动目录
要求在需要制作目录的位置上使用[m]这样的shortcode,相应功能实现见shortcode/menu.php
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */

//从内容中寻找目录内容，生成目录
(function($){
  var main=$('.entry-content');
  if (main.length<1) return;
  var article_menus=$('.article_menus');
  main.each(function () {
    var that=$(this);
    var menus=that.find('.auto_menu');
    if (menus.length<1) return;
    $('.article_menus_a').removeClass('hidden');
    var menuHtml='<div class="article_menu"><h2>文章目录</h2><div class="ul_cont"><div class="scroll-div"><ul class="scroll-main">';
    menus.each(function () {
      var index=menus.index($(this));
      var menuId='menu_'+index;
      $(this).attr('id',menuId);
      menuHtml+='<li><a href="#'+menuId+'"><span>'+$(this).text()+'</span></a></li>';
    });
    menuHtml+='</ul><span class="scroll-model"><em></em></span></div></div></div>';
    //that.children('p').eq(0).after(menuHtml);
    if (article_menus.length>0) {
      article_menus.html(menuHtml);
      setTimeout(function () {
        article_menus_init();
      },0);
    }
  });
  $(window).on('resize',article_menus_init);

  function article_menus_init(){
    var a=$('#article_menus');
    if (a.length<1) return;
    var b=a.find('.scroll-div');
    var c=b.find('.scroll-main');
    var aOffset=a.offset();
    var st=window.pageYOffset
    			|| document.documentElement.scrollTop
    			|| document.body.scrollTop
    			|| 0;
    var height=b.height()-parseFloat(c.css('margin-top'));
    if (b.attr('data-height')-0>0) {
    }else{
      b.attr('data-height',height);
    }
    var originalHeight=b.attr('data-height')-0 || height;
    var gap=aOffset.top-(originalHeight-height)-st-80;
    needScrollDel(b);
    if (gap<0) {
      b.addClass('needScroll');
      b.css({
        'max-height': originalHeight+gap,
        'min-height': originalHeight+gap
      });
      setTimeout(needScrollInit,0);
    }else{
      b.removeClass('needScroll');
      b.css({
        'max-height': 'none',
        'min-height': 'none'
      });
    }
  }

  function needScrollDel(j){
    j.off('mousewheel');
    var em=j.find('.scroll-model em');
    em.css({
      top:0
    });
    j.css({
      'margin-top':0
    });
  }

  function needScrollInit(){
    $('.needScroll').each(function () {
      needScrollDel($(this));
      var oh=$(this).attr('data-height')-0;
      if (oh<=0 || isNaN(oh)) return;
      var h=$(this).height();
      var per=100*h/oh;
      var em=$(this).find('.scroll-model em');
      em.off('mousedown');
      $(window).off('mouseup',emMouseUp);
      em.css({
        height:per+'%',
      });
      var t=$(this).find('.scroll-main');
      if (t.length<1) return;
      var tmax=oh-h;//scroll-main能用于移动的总的数值
      $(this).on('mousewheel',function (e) {
        var delta=e.originalEvent.wheelDelta;
        var step=delta*1;
        var n=t.css('margin-top');
        var now=parseInt(n);
        var mt=now+step;
        if (mt>=0) mt=0;
        if (mt<=0-tmax) mt=0-tmax;
        t.css({
          'margin-top': mt
        });
        var eTop=(0-mt)/tmax*(100-per);
        em.css({
          top:eTop+'%'
        });
        return false;
      });
      em.on('mousedown',function (e) {
        $(this).addClass('hover');
        em.attr('data-mousedown',1);
        em.attr('data-mouseY',e.clientY);
      });
      $(window).on('mouseup',emMouseUp);
      function emMouseUp(){
        em.removeClass('hover');
        em.attr('data-mousedown',0);
      }
      $(window).on('mousemove',function (e) {
        if (em.attr('data-mousedown')==1) {
          var originalY=em.attr('data-mouseY')-0;
          var gap=e.clientY-originalY;
          var min=0;
          var max=h*(100-per)/100;
          var now=parseFloat(em.css('top'))-0;
          var step=now+gap;
          if (step<=min) step=min;
          if (step>=max) step=max;
          var eper=step/max;
          em.css({
            'top':step
          });
          t.css({
            'margin-top':0-eper*tmax
          });
          em.attr('data-mouseY',e.clientY);
          return false;
        }
      });
    });
  }


  //文章页右侧菜单的显隐操作
  var btn=$('.m-article');
  if(btn.length<1) return;
  btn.on('click',function () {
    return false;
  });
  $('.m-code').on('click',function () {
    return false;
  });
  btn.on('mouseenter',function () {
    $(this).addClass('hoving');
    $('.article_menus').removeClass('hidden');
    article_menus_init();
  });
  btn.on('mouseleave',function () {
    $(this).removeClass('hoving');
  });
  btn.on('click',function () {
    if ($(this).hasClass('hoving')) {
      $(this).removeClass('hoving');
    }else{
      $('.article_menus').toggleClass('hidden');
      $(document).trigger('article_menu_span_init');
      article_menus_init();

    }
  });
  if (orz.isMobile()!=false) {
    btn.off('mouseenter');
    btn.off('mouseleave');
    $(document).on('touchend',function (e) {
      if ($(e.target).hasClass('fixed_menus_new') || $(e.target).parents('.fixed_menus_new').length>0) {
        console.log('mobile click');
        //btn.trigger('click');
      }else{
        setTimeout(function () {
          $('.article_menus').addClass('hidden');
          needScrollDel($('#article_menus .scroll-main'));
        },10);
      }
    });
    $('.fixed_menus_new .article_menus li a').on('click',function () {
      $('.article_menus').addClass('hidden');
      needScrollDel($('#article_menus .scroll-main'));
    });
  }
  $('.fixed_menus_new').on('mouseleave',function () {
    $('.article_menus').addClass('hidden');
    needScrollDel($('#article_menus .scroll-main'));
  });
  $('.ewm').on('mouseenter',function () {
    $('.article_menus').addClass('hidden');
    needScrollDel($('#article_menus .scroll-main'));
  });
})(jQuery);

//菜单项的current显示
jQuery(function ($){
  $('.article_menu a').on('click',function () {
    var id=$(this).attr('href').substring(1);
    var target=$('#'+id);
    if (target.length<1) return;
    var tOffset=target.offset();
    var tTop=tOffset.top;
    $('html,body').animate({
      scrollTop:tTop-80
    },10);
    return false;
  });
  $(window).on('scroll',function () {
    var st=window.pageYOffset
    			|| document.documentElement.scrollTop
    			|| document.body.scrollTop
    			|| 0;
    $('.article_menu a').each(function () {
      var id=$(this).attr('href').substring(1);
      var target=$('#'+id);
      if (target.length<1) return;
      var tOffset=target.offset();
      var tTop=tOffset.top;
      if (st>tTop-90) {
        $('.article_menu a').removeClass('current');
        $(this).addClass('current');
      }
    });
  });
  $('.m-top').on('click',function () {
    $('html,body').animate({
      scrollTop:0
    },10);
    return false;
  });
});

(function($){
  //右侧浮动菜单的宽度初始化
  function spanInit(){
    var cl=document.documentElement.clientWidth;
    var t=$('.fixed_menus_new .ul_cont li span');
    if (t.length<1) return;
    var tOffset=t.offset();
    if (!orz.isMobile()) {
      t.css({
        'max-width':cl-tOffset.left-12
      });
    }else{
      if(tOffset.left < 0) {
        t.css({
          //'max-width': t.width()+tOffset.left
          'max-width': cl-140
        });
      }
    }
  }
  $(document).on('article_menu_span_init',spanInit);
  $(document).trigger('article_menu_span_init');
  $(window).on('resize',function () {
    $(document).trigger('article_menu_span_init');
  });
})(jQuery);

//右侧菜单在白底时才显示
(function($){
  var a=$('#article_menus');//用于判断是不是文章页
  if (a.length<1) return;
  var b=a.children('.article_menu');//用于判断有没有菜单
  if (b.length<1) return;
  $(window).on('scroll',function () {
    var st=window.pageYOffset
    			|| document.documentElement.scrollTop
    			|| document.body.scrollTop
    			|| 0;
    var ct=document.documentElement.clientHeight;
    var stop1=$('.page-wrap').offset();
    var stop2=$('.single-footer-zt').offset();
    if (st<stop1.top || st>stop2.top-ct) {
      $(document).trigger('article_menus_not_show');
    }else{
      $(document).trigger('article_menus_show');
    }
  });
  function article_menus_show_fn(){
    a.removeClass('notShow');
  }
  function article_menus_not_show_fn(){
    a.addClass('notShow');
  }
  $(document).on('article_menus_show',article_menus_show_fn);
  $(document).on('article_menus_not_show',article_menus_not_show_fn);
})(jQuery);

/* ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
侧边栏文章推荐版块切换
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
(function($){
  orz.sidebar_post_recommend_event=function () {
    var bar=$('.sidebar-post-recommend');
    if (bar.length<1) return;
    bar.each(function () {
      var tabs=$(this).find('.title-tabs>span');
      var items=$(this).find('.reco-items');
      if (tabs.length<1) return;
      if (items.length<1) return;
      tabs.hover(function () {
        var index=tabs.index($(this));
        tabs.removeClass('current');
        $(this).addClass('current');
        items.addClass('hidden');
        items.eq(index).removeClass('hidden');
      });
    });
  };
})(jQuery);

/* ---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=*
话题
---=*--*=*-=*-=-*-=* ^.^ *---=*--*=*-=*-=-*-=* */
jQuery(function ($){
  $(document).on('pageDataLoaded',function () {
    if (orz.isUserLogin()) {
      $('[data-logined-target]').each(function () {
        orz.setAttr('modal-id',$(this).attr('data-logined-target'),$(this));
      });
    }
  });
  orz.click(function (){
    $(this).siblings('.share_ul').toggleClass('show');
  },'.talk-items .share-div h3');
  orz.click(function (){
    $(this).parent('.share_ul').toggleClass('show');
  },'.talk-items .share-div .close-li');
});

/**
 * 搜索表单提交的时候要做检查
 */
(function($){
  $('.talk_search_form').on('submit',function (){
    var val=orz.get_form_item_val('s',this);
    $(this).find('[name=s]').val(val);
  });
})(jQuery);

/**
 * 话题提交
 */
jQuery(function ($){
  function echo_error(error,ele){
    orz.show($(ele).find('.error')).children('p').html(error);
  }
  function hide_error(ele){
    orz.hidden($(ele).find('.error'));
  }
  $('.is_anonymous').on('change',function () {
    if($(this).prop('checked')) {
      $(this).val('yes');
    }else{
      $(this).val('no');
    }
  });
  $('body').on('focusin','.talk_title',function (){
    hide_error($(this).parent().parent());
  });
  $('.talk_write_form').on('submit',function (){
    var title=orz.trim(orz.get_form_item_val('talk_title',this));
    var desc=orz.trim(orz.get_form_item_val('talk_desc',this));
    var is_anonymous=orz.get_form_item_val('is_anonymous',this);
    var error='';
    if (orz.isEmpty(title)) error+='请输入标题';
    if (orz.isNotEmpty(error)) {
      echo_error(error,$(this));
      return false;
    }
    orz.post(function (res){
      res=orz.jsonDecode(res);
      var error='';
      if (res) {
        if (orz.isNotEmpty(res.error)) {
          error=res.error;
        }else {//发布成功

        }
      }else{
        error='出错了，请重试。';
      }
      if (orz.isNotEmpty(error)) {
        echo_error(error,this);
        return false;
      }
    },{
      'action':'post_talk',
      'title':title,
      'desc':desc,
      'is_anonymous':is_anonymous
    },this);
    return false;
  });
});
/**
 * 话题单页专享脚本
 */
jQuery(function ($){
  var single=$('.talk-single');
  if (single.length<1) return;
  var main=single.children('.talk-main');
  var sidebar=single.children('.talk-sidebar');

  /**
   * 话题单页内容中meta内的comment显示评论数
   */
  function comment_count_init() {
    var t=$('.comment_count');
    if (t.length<1) return;
    if (orz.commentCount()>0) t.html(orz.commentCount());
  }

  /**
   * 话题单页点赞初始化
   */
  function item_zan_init(){
    var t=$('.talk-single .section-content [data-component=zan]');
    if (t.length<1) return;
    var pageData=orz.pageData();
    console.dir(orz.attr('pid',t));
    if (orz.has_post_zan(orz.attr('pid',t))) {
      t.addClass('has_zan');
    }
    if (pageData.zan_count>0) t.find('.zan_count').html(pageData.zan_count);
  }

  /**
   * 评论加载后去掉评论加载中提示
   */
  function comment_loaded() {
    $('.talk-section-comments .loading').addClass('hidden');
    $('.talk-section-comments .comments-content').removeClass('hidden');
  }

  /**
   * 评论大标题初始化
   */
  function comments_title_init() {
    var word='当前还未有评论';
    if (orz.commentCount()>0) word='全部'+orz.commentCount()+'条评论';
    $('.comments-content .comments-title').html(word);
  }

  /**
   * 未有评论
   */
  function no_comments_init() {
      if (orz.commentCount()<1) $('.no-comments').removeClass('hidden');
  }

  function get_comments_html(comments){
    var html='';
    var author,author_url,parent_author,content,id,parent,zan,meta,time,has_zan;
    for (var i=0;i<comments.length;i++) {
      id=comments[i].id;
      parent=comments[i].parent;
      time=comments[i].time;
      author=comments[i].author;
      author_url=comments[i].author_url;
      parent_author=comments[i].parent_author;
      content=orz.content_filter(comments[i].content);
      content='<div class="comment-content">'+content+'</div>';
      zan=comments[i].zan;
      if (zan<1) zan='';
      has_zan=orz.has_comment_zan(id) ? 'has_zan':'';
      meta='<div class="comment-meta"><span class="zan '+has_zan+'" data-component="zan" data-cid="'+id+'"><i class="icon-zan"></i> <em class="zan_count">'+zan+'</em>赞</span><span class="comment-reply" data-cid="'+id+'"><i class="icon-reply"></i>回复</span></div>';
      time='<div class="comment-time">'+orz.getDateDiff(time)+'</div>';
      if (comments[i].parent<1) {
        if (i>0) {
          html+='</div>';//item-main
          html+='</div>';//comment-item
        }
        html+='<div class="comment-item" id="comment-'+id+'">';
        html+='<a href="'+author_url+'" target="_blank"><div class="avatar" style="background-image: url('+$(comments[i].avatar).attr('src')+');"></div></a>';
        html+='<div class="item-main">';
        html+='<div class="comment-title"><a href="'+author_url+'" target="_blank">'+author+'</a></div>';
        html+=content;
        html+=meta;
        html+=time;
      }else{
        html+='<div class="item-child" id="comment-'+id+'">';
        html+='<div class="comment-title"><a href="'+author_url+'" target="_blank">'+author+'</a> 回复 <a href="#comment-'+parent+'"> '+parent_author+'</a></div>';
        html+=content;
        html+=meta;
        html+=time;
        html+='</div>';//item-child
      }
    }
    html+='</div>';//item-main
    html+='</div>';//comment-item
    return html;
  }

  /**
  * 评论列表初始化
  */
  function comments_init() {
    if (orz.commentCount()<1) return;
    var items= $('.comment-items');
    items.removeClass('hidden');
    var comments=orz.commentList();
    var html=get_comments_html(comments);
    items.html(html);
  }
  function comments_add(html){
    $('.comment-items').append(html);
  }

  /**
  * 更多评论显隐
  */
  function comment_more_init() {
    var pagedata=orz.pageData();
    if (pagedata.comment_per_page <= pagedata.comment_list.length) {
      more_active();
    }
  }
  function more_disable() {
    $('.comment-more .btn').addClass('btn-disable');
    $('.comment-more').addClass('hidden');
  }
  function more_active() {
    $('.comment-more').removeClass('hidden');
    $('.comment-more .btn').removeClass('btn-disable');
  }
  var get_more_pid=orz.attr('pid');
  var get_more_paged=orz.attr('paged');
  var add_loading=orz.addClass('btn-loading');
  var remove_loading=orz.removeClass('btn-loading');
  var is_loading=orz.hasClass('btn-loading');

  orz.click(function (){
    if (is_loading(this)) return;
    add_loading(this);
    var data={
      action:'comment_list',
      pid:get_more_pid(this),
      paged:get_more_paged(this)
    };
    orz.post(function (res){
      res=orz.jsonDecode(res);
      remove_loading(this);
      if (res.length<uisdc.pageData.comment_per_page) {
        more_disable();
      }
      comments_add(get_comments_html(res));
    },data,this);
  },'#comment_more');

  /**
  * 评论表单生成
  */
  function get_comment_form(cid){
    var opt='<div class="comment-form comment-item">';
    var avatar=orz.get_comment_avatar();
    cid=cid || 0;
    opt+='<div class="avatar" style="background-image:url('+avatar+');"></div>';
    opt+='<div class="item-main">';
    opt+='<form action="#" method="post" data-parent="'+cid+'" class="comment-form-write">';
    opt+='<div class="form-item">';
    opt+='<textarea class="comment-content txt2 lineLen" name="comment_content" data-total="800" data-placeholder="你觉得怎么样？说说看"></textarea>';
    opt+='<span class="total_count hidden">还可以输入<i class="count"></i>字</span>';
    opt+='</div>';
    opt+='<div class="form-item">';
    opt+='<div class="form-captcha hidden"><input type="text" class="txt txt_yzm txt_empty" name="captcha_code" data-placeholder="请输入验证码"><img src="#" class="captcha_img"><input type="hidden" class="hidden" name="captcha_prefix"></div>';
    opt+='<button type="submit" class="btn" name="submit" value="comment-submit">发表评论</button>';
    opt+='<p class="error"></p>';
    opt+='</div>';
    opt+='</form>';
    opt+='</div>';
    opt+='<span class="close"><i class="icon-close"></i></span>';
    opt+='</div>';
    return opt;
  }

  /**
  * 页面载入时在评论列表上面显示评论表单
  */
  function comment_form_init(){
    remove_all_comment_form();
    $('.comment-items').before(get_comment_form());
    $('body').trigger('form.placeholder.ready');
  }

  /**
  * 话题侧边栏自动停靠
  */
  function talk_sidebar_auto_fixed(){
    var st=window.pageYOffset
    || document.documentElement.scrollTop
    || document.body.scrollTop
    || 0;
    var header_top=$('#header-bg.scrolling').outerHeight()-0;
  }

  /**
  * 清除所有的评论表单
  */
  function remove_all_comment_form(){
    $('.comment-form').remove();
  }

  function update_captha(form){
    if(!orz.isUserLogin()){
      orz.get_captcha($(form).find('.form-captcha'));
    }
  }

  $(document).on('pageDataLoaded',function () {
    comment_count_init();
    item_zan_init();
    comment_loaded();
    comments_title_init();
    no_comments_init();
    comment_form_init();
    comments_init();
    comment_more_init();
    talk_sidebar_auto_fixed();
  });

  /**
  * 评论表单提交
  */
  $('body').on('submit','.comment-form-write',function (){
    var content=orz.get_form_item_val('comment_content',this);
    var captcha_code=orz.get_form_item_val('captcha_code',this);
    var captcha_prefix=orz.get_form_item_val('captcha_prefix',this);
    var parent=orz.attr('parent',this);
    var error='';
    if (orz.isEmpty(content)) error+='请填写评论内容';
    if (!orz.isUserLogin() && orz.isEmpty(captcha_code)) error+='，请填写验证码';
    if (orz.isNotEmpty(error)) {
      orz.echo_comment_error(this,error);
      return false;
    }
    orz.disable($(this).find('[name=submit]')).html('评论提交中...');
    var data={
      action:'post_comment',
      pid:uisdc.status.postid,
      user:'',
      comment:content,
      parent:parent,
      captcha_code:captcha_code,
      captcha_prefix:captcha_prefix,
      device:orz.getDevice()
    };
    orz.post(function (res){
      var error='';
      var html='';
      res=orz.jsonDecode(res);
      if (orz.isNotEmpty(res)) {
        error=res.error;
        if(orz.isEmpty(error)){//成功返回
          var t=res[0];
          var id=t.id;
          var avatar=orz.get_comment_avatar();
          var author=t.author;
          var content=t.content;
          html+='<div class="comment-item comment-unproved" id="comment-'+id+'"><div class="avatar" style="background-image: url('+avatar+');"></div><div class="item-main"><div class="comment-title">'+author+'<em class="approved_em">您的评论正在等待审核~</em></div><div class="comment-content">'+content+'</div><div class="comment-time">刚刚</div></div></div>';
          $('.comment-items').prepend(html);
          comment_form_init();
          //鼠标再滚回评论顶部
          orz.scrollTo($('#single_comment'));
        }
      }else{
        error='出错了，请重试。';
      }
      if (orz.isNotEmpty(error)) {
        orz.echo_comment_error(this,error);
      }
      update_captha(this);
      orz.enable($(this).find('[name=submit]')).html('发表评论');
    },data,this);
    return false;
  });

  /**
  * 评论列表中回复按钮点击
  */
  orz.click(function (){
    var parent=$(this).parent();
    var cid=orz.attr('cid',$(this));
    remove_all_comment_form();
    parent.after(get_comment_form(cid));
    $('body').trigger('form.placeholder.ready');
  },'.comment-reply');

  var get_total=orz.attr('total');

  /**
  * 获取剩余字数
  */
  function get_rest(ele){
    return get_total($(ele))-$(ele).val().length;
  }

  /**
  * 在total_count中设置剩余字数
  */
  function set_total_count(ele,val){
    $(ele).find('.count').html(val);
  }

  /**
  * 评论列表的内容输入框点击，显示可输入字数，根据需要显示验证码
  */
  orz.click(function (){
    var yzm=$(this).parent().parent().find('.form-captcha');
    var total_count=$(this).siblings('.total_count');
    orz.lineLen();
    if(!orz.isUserLogin()){
      if (!orz.isInit(yzm)) orz.get_captcha(yzm);
    }
    set_total_count(total_count,get_rest(this));
    orz.show(total_count);
  },'.comment-content');

  $('body').on('keyup','.comment-content',function (){
    var total_count=$(this).siblings('.total_count');
    set_total_count(total_count,get_rest(this));
    $(this).val($(this).val().substring(0,get_total(this)));
    orz.setLine(this);
    orz.show(total_count);
  });
  $('body').on('focusin','.comment-content',function (){
    var total_count=$(this).siblings('.total_count');
    set_total_count(total_count,get_rest(this));
    orz.show(total_count);
    orz.hidden('.comment-form-write .error');
  });
  $('body').on('focusout','.comment-content',function (){
    var total_count=$(this).siblings('.total_count');
    orz.hidden(total_count);
  });
  $('body').on('focusin','.txt_yzm',function (){
    orz.hidden('.comment-form-write .error');
  });

  orz.click(function (){
    orz.get_captcha($(this).parent().parent());
  },'.captcha_img');
  /**
  * 评论表单关闭按钮,点击时删除所有评论表单，还原最上面的评论表单
  */
  orz.click(comment_form_init,'.comment-form .close');

  $(window).on('resize',talk_sidebar_auto_fixed);
  $(window).on('scroll',orz.scroll(talk_sidebar_auto_fixed));
});

/** ---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=*
 * @Name 话题侧边栏脚本
 * @Author lizus.com
 *
---=*--*=*-=*-=-*-=* 🌹 *---=*--*=*-=*-=-*-=* */
jQuery(function ($){
  var toTop=77;//fixed的时候，距离顶部的距离
  var sidebar=$('.talk-sidebar');
  if (sidebar.length<1) return;
  var m=sidebar.parent();
  var auto_fixed=sidebar.find('.auto_fixed');//单个需要停靠
  var multi_fixed=sidebar.find('.multi_fixed');//多个需要停靠
  var sidebar_multi=$('<div class="sidebar_multi"></div>');
  function fixed_func(ele){
    if (sidebar.height()+auto_fixed.height()>=m.height()) {
      return;
    }
    var st=window.pageYOffset
    			|| document.documentElement.scrollTop
    			|| document.body.scrollTop
    			|| 0;
    var before_target=$(ele).prev();
    var sidebar_offset=sidebar.offset();
    var m_offset=m.offset();
    var fix_start=Math.round(sidebar_offset.top);
    var absolute_start=Math.round(m_offset.top+m.outerHeight()-$(ele).outerHeight());
    if (before_target.length>0) {
      fix_start=Math.round(before_target.offset().top+before_target.outerHeight()+parseInt(before_target.css('margin-bottom')));
    }
    fix_start=fix_start-toTop;
    absolute_start=absolute_start-toTop;
    $(ele).removeClass('side_fixed');
    $(ele).removeClass('side_absolute');
    if (!orz.sm()) return;
    if (st>fix_start) {
      $(ele).addClass('side_fixed');
      $(ele).removeClass('side_absolute');
    }
    if (st>absolute_start) {
      $(ele).removeClass('side_fixed');
      $(ele).addClass('side_absolute');
    }
  }
  if (multi_fixed.length>0) {
    sidebar_multi.append(multi_fixed.clone(true));
    sidebar.append(sidebar_multi);
    auto_fixed=sidebar_multi;
  }
  fixed_func(auto_fixed);
  $(window).on('scroll',orz.scroll(function (){
    fixed_func(auto_fixed);
  }));
  $(window).on('resize',function (){
    fixed_func(auto_fixed);
  });
});

(function($){
  function get_history(){
    var cookie=orz.getCookie('search_history');
    cookie=orz.jsonDecode(cookie);
    if (orz.isEmpty(cookie) || !orz.isObject(cookie)) {
      cookie={};
    }
    return cookie;
  }

  function set_history(){
    var s_history=get_history();
    var s=orz._get('s');
    if (orz.isNotEmpty(s)) {
      s=decodeURIComponent(s);
      delete(s_history[s]);
      s_history[s]=new Date().getTime();
      orz.setCookie('search_history',orz.jsonEncode(s_history));
    }
  }

  function remove_history_tag(){
    var s_history=get_history();
    delete(s_history[$(this).attr('data-tag')]);
    orz.setCookie('search_history',orz.jsonEncode(s_history));
    $(this).parent().remove();
  }

  function remove_all_history(){
    orz.setCookie('search_history','');
    $(this).remove();
    $('#search_history').html(get_lis({}));
  }

  var lpad2=orz.lpad('0',2);

  function get_time(t){
    var d=new Date();
    d.setTime(t);
    return lpad2(d.getMonth()+1)+'-'+lpad2(d.getDate())+' '+lpad2(d.getHours())+':'+lpad2(d.getMinutes());
  }

  function short_text(txt,len){
    if (txt.length>len) {
      txt=txt.substring(0,len)+'...';
    }
    return txt;
  }

  function get_href(s){
    return orz.currentPageUrl()+'?s='+s;
  }

  function get_lis(obj){
    var opt=[];
    if (orz.isObject(obj)) {
      for (var prop in obj) {
        if (obj.hasOwnProperty(prop)) {
          opt.unshift('<li><span>'+get_time(obj[prop])+'</span><a href="'+get_href(prop)+'" title="'+prop+'">'+short_text(prop,8)+'</a><i class="icon-close search-tag-close" data-tag="'+prop+'"></i></li>');
        }
      }
    }
    if (orz.isEmpty(opt)) {
      opt=['你还没搜索过喔。'];
    }
    opt=opt.slice(0,12);
    return opt.join('');
  }

  //清除所有历史记录
  function get_clear_all_btn(){
    var t=$('.search-widget-history .widget-title');
    if (t.length<1) return;
    var h=get_history();
    var keys=Object.keys(h);
    orz.log(keys);
    if (keys.length>0) {
      t.append('<span class="clear-all-history">全部清除</span>');
    }
  }


  var body=$('body.search');
  if (body.length<1) return;
  set_history();
  var h=get_history();
  var html=get_lis(h);
  var target=$('#search_history');
  if (target.length>0) {
    target.html(html);
  }
  orz.click(remove_history_tag,'.search-tag-close');
  orz.click(remove_all_history,'.clear-all-history');

  get_clear_all_btn();

  $('.search-item').on('click',function (){
    if (!orz.sm()) {
      document.location=$(this).children('h3').children('a').attr('href');
      return false;
    }
  });

})(jQuery);

(function($){

  $('form').on('submit',function (){
    var s=$(this).find('[name=s]');
    if (s.length>0) {
      if (s.val()==s.attr('data-placeholder')) {
        s.val('');
      }
    }
  });

})(jQuery);

(function($){
  //右侧auto_fixed
  var sp=$('.search-sidebar');
  var s=$('.search-sidebar .auto_fixed');
  if (sp.length<1) return;
  if (s.length<1) return;
  var m=$('.search-main');
  if (m.length<1) return;
  var sf=s.offset();
  var sft=sf.top;
  var mf=m.offset();
  $(document).on('pageDataLoaded',sp_init);
  function sp_init(){
    s.removeClass('fixed_animate');
    s.removeClass('sidebar_absolute');
    sf=s.offset();
    sft=sf.top;
    mf=m.offset();
    var cl=document.documentElement.clientWidth;
    if (cl>768) {
      //sp.height(m.height());
      auto_fixed();
    }
  }
  $(window).on('resize',sp_init);
  $(window).on('scroll',orz.scroll(auto_fixed));
  function auto_fixed() {
    var cl=document.documentElement.clientWidth;
    if (cl<768) return;
    var st=$(document).scrollTop();
    if (st>sft) {
      if (!s.hasClass('fixed_animate')) s.addClass('fixed_animate');
      if (st+s.outerHeight()>=m.height()+mf.top) {
        if (!s.hasClass('sidebar_absolute')) {
          s.addClass('sidebar_absolute');
        }
      }else {
        s.removeClass('sidebar_absolute');
      }
    }else {
      s.removeClass('fixed_animate');
      s.removeClass('sidebar_absolute');
    }
  }
})(jQuery);

(function($){
  var placeholder=orz.attr('placeholder');
  function type(ele){
    $(ele).each(function (){
      var str=placeholder(this);
      var i = 0,
      timer = 0;
      var that=this;

      function typing () {
        if (!$(that).hasClass('placeholder')) {
          i=0;
          clearTimeout(timer);
          return;
        }
        if (i <= str.length) {
          $(that).val(str.slice(0, i++) + '_');
          timer = setTimeout(typing, 200);
        }
        else {
          $(that).val(str);//结束打字,移除 _ 光标
          //clearTimeout(timer);
          i=0;
          timer = setTimeout(typing, 5000);
        }
      }
      typing();
      $(that).on('focusin',function (){
        if ($(this).hasClass('placeholder')) {
          $(this).val('');
        }
      });
      $(that).on('focusout',function (){
        i=0;
        setTimeout(typing,1000);
      });
    });
  }
  type('.home .search-text');
  $('.search-form').on('submit',function (){
    $(this).find('.placeholder').val('');
  });


})(jQuery);

/*******************************************************************
 * -> init.js
**--> Author: lizus.com@gmail.com
**--> WebSite: http://lizus.com
*******************************************************************/

//Markup external link;
jQuery(function ($){
	$("a[href*='http://']:not([href*='"+location.hostname+"']),[href*='https://']:not([href*='"+location.hostname+"'])").addClass("external").attr("target","_blank");
});

//顶部菜单激活状态


//新开窗口
(function($){
	$('.aside a').attr('target','_blank');
	//$('.entry-content a').attr('target','_blank');
	$('.entry-content a').each(function () {
		var href=$(this).attr('href');
		if (href && href.indexOf('#') == 0) return;
		$(this).attr('target','_blank');
	});
	$('.current-page-header a').attr('target','_blank');
	$('.current-page-header .not_blank').attr('target','_self');
	//$('.single-top-menu a').attr('target','_blank');
})(jQuery);


//左侧边栏与主栏高度一致
(function($){
	function aside_init() {
		var s=$('#sidebar');
		if (s.length<1) return;
		var c=$('#content');
		var cw=$('#content-wrap');
		var p=cw.find('.post-main');
		var ch=0;
		if (cw.length>0) ch=cw.height();
		if (c.length>0) ch=c.height();
		if (p.length>0 && !$('body').hasClass('page')) ch=p.height()+120;
		s.css('min-height',Math.floor(ch));
		$(document).trigger('afterAsideInit');
	}
	runOnLoad(function () {
		aside_init();
	});
	$('body').on('aside_init',aside_init);
	$(window).on('resize',aside_init);
})(jQuery);

//右侧边栏Tab
(function($){
	var a=$('.article-tab');
	if(a.length<1) return;
	var ul=a.children('ul');
	var t=a.find('.tabs-line span');
	t.hover(function () {
		t.removeClass('current');
		$(this).addClass('current');
		var index=t.index($(this));
		ul.addClass('hidden');
		ul.eq(index).removeClass('hidden');
	});
})(jQuery);

//modal 模态弹窗
jQuery(function ($){
	$('body').on('click','.modal-open',function () {
		var id=$(this).attr('data-modal-id');
		var mask=$(this).attr('data-modal-mask');
		if (!id) return;
		if(mask!='no') $('.modal-mark').addClass('modal-show');
		$('#'+id).trigger('modal.show',$(this));
		$('#'+id).addClass('modal-show');
		return false;
	});
	$('body').on('click','.modal-close',modalClose);
	$('body').on('click','.modal-mark',modalClose);
	function modalClose() {
		$('.modal-show').removeClass('modal-show');
		$('.modal-show').trigger('modal.close');
		return false;
	}
});

(function($){
	$(document).on('pageDataLoaded',function () {
		orz.sidebar_post_recommend_event();
	})
})(jQuery);

//侧栏停告,文章页
jQuery(function ($){
	var single=$('body.single');
  var s=$('#sidebar');
  var ss=s.find('.need_fixed');
	if(single.length<1) {
		ss=s.find('.list_need_fixed');
	}
  if (s.length<1) return;
  if (ss.length<1) return;
  var m=$('#content-wrap');
  if (m.length<1) return;
  var html=$('<div class="sidebar_fixed"></div>');
	ss.each(function () {
		html.append($(this).clone(true,true).removeClass('hidden'));
	})
	var lastChild=s.children(':last-child');
  s.append(html);
  html.find('.book-recom li').each(function (index,item) {
    if (index>2) {
      $(this).remove();
    }
  });
	var sft=lastChild.offset().top+lastChild.outerHeight();
	var mf=m.offset();
	function sf_init(){
		sft=lastChild.offset().top+lastChild.outerHeight();
    mf=m.offset();
		auto_fixed();
	}
	$(document).on('afterAsideInit',sf_init);
  $(window).on('scroll',orz.scroll(auto_fixed));
  function auto_fixed() {
      var st=$(document).scrollTop();
      if (st>sft) {
        html.addClass('fixed_animate');
        if (st+html.height()+120>=m.height()+mf.top) {
          html.addClass('sidebar_absolute');
        }else {
          html.removeClass('sidebar_absolute');
        }
      }else {
        html.removeClass('fixed_animate');
        html.removeClass('sidebar_absolute');
      }
  }
});

//左侧auto_fixed,列表页
jQuery(function ($){
	var single=$('body.single');
  if (single.length>0) return;
	var sp=$('#sidebar');
	var s=$('#sidebar .auto_fixed');
  if (sp.length<1) return;
  if (s.length<1) return;
  var m=$('#content-wrap');
  if (m.length<1) return;
	var mc=$('#content');
	if (mc.length<1) mc=m.children('.post-main');
	var sf=s.offset();
  var sft=sf.top;
	var mf=m.offset();
	function sp_init(){
		//s.removeClass('fixed_animate');
		//s.removeClass('sidebar_absolute');
    sf=s.offset();
    sft=sf.top;
    mf=m.offset();
		auto_fixed();
	}
	$(document).on('afterAsideInit',sp_init);
  $(window).on('resize',sp_init);
  $(window).on('scroll',orz.scroll(auto_fixed));
	function auto_fixed() {
		var st=$(document).scrollTop();
		if (st>sft-79) {
			s.addClass('fixed_animate');
			if (st+s.outerHeight()>=m.height()+mf.top-79) {
				s.addClass('sidebar_absolute');
			}else {
				s.removeClass('sidebar_absolute');
			}
		}else {
			s.removeClass('fixed_animate');
			s.removeClass('sidebar_absolute');
		}
  }
});


//右侧auto_fixed,列表页
jQuery(function ($){
	var sp=$('#sidebar-secondary');
	var s=$('#sidebar-secondary .auto_fixed');
  if (sp.length<1) return;
  if (s.length<1) return;
  var m=$('#content-wrap');
  if (m.length<1) return;
	var sf=s.offset();
  var sft=sf.top;
	var mf=m.offset();
	$(document).on('pageDataLoaded',sp_init);
	function sp_init(){
		s.removeClass('fixed_animate');
		s.removeClass('sidebar_absolute');
    sf=s.offset();
    sft=sf.top;
    mf=m.offset();
		var cl=document.documentElement.clientWidth;
		if (cl>768) {
			//sp.height(m.height());
			auto_fixed();
		}
	}
  $(window).on('resize',sp_init);
  $(window).on('scroll',orz.scroll(auto_fixed));
	function auto_fixed() {
		var cl=document.documentElement.clientWidth;
		if (cl<768) return;
		var st=$(document).scrollTop();
		if (st>sft-77) {
			if (!s.hasClass('fixed_animate')) s.addClass('fixed_animate');
			if (st+s.outerHeight()>=m.height()+mf.top-58) {
				if (!s.hasClass('sidebar_absolute')) {
					s.addClass('sidebar_absolute');
				}
			}else {
				s.removeClass('sidebar_absolute');
			}
		}else {
			s.removeClass('fixed_animate');
			s.removeClass('sidebar_absolute');
		}
  }
});

jQuery(function ($){
	var s=$('.single-top-menu');
	if(s.length<1) return;
	var so=s.offset();
	s.on('fixed.on',function () {
		if (!$(this).hasClass('top-menu-fixed')) {
			$(this).addClass('top-menu-fixed');
		}
	});
	s.on('fixed.off',function () {
		if ($(this).hasClass('top-menu-fixed')) {
			$(this).removeClass('top-menu-fixed');
		}
	});
	$(window).on('resize',function () {
		s.removeClass('top-menu-fixed');
		so=s.offset();
		$(window).trigger('scroll');
	});
	$(window).on('scroll',orz.scroll(function () {
		var st=window.pageYOffset
					|| document.documentElement.scrollTop
					|| document.body.scrollTop
					|| 0;
		if (st>so.top) {
			s.trigger('fixed.on');
		}else {
			s.trigger('fixed.off');
		}
	}));
});

(function($){
	$('.has_border').each(function () {
		$(this).html('<em>'+$(this).html()+'</em>');
	});
})(jQuery);

//文章页左右翻按钮
jQuery(function ($){
	$(window).on('scroll',orz.scroll(function () {
		var st=window.pageYOffset
					|| document.documentElement.scrollTop
					|| document.body.scrollTop
					|| 0;
		var ct=document.documentElement.clientHeight;
		if (st>ct) {
			if($('.fixed_a').hasClass('hidden')) $('.fixed_a').removeClass('hidden');
			//if($('#back-top').hasClass('hidden')) $('#back-top').removeClass('hidden');
			//if($('#backtop').hasClass('hidden')) $('#backtop').removeClass('hidden');
		}else{
			if(!$('.fixed_a').hasClass('hidden')) $('.fixed_a').addClass('hidden');
			//if(!$('#back-top').hasClass('hidden')) $('#back-top').addClass('hidden');
			//if(!$('#backtop').hasClass('hidden')) $('#backtop').addClass('hidden');
		}
	}));
});

jQuery(function ($){
	$('.entry-content p').each(function () {
		if ($(this).find('img').length>0) return;
		$(this).css({
			'max-width':750
		});
	});
});

/*
runOnLoad(function () {
	jQuery('.entry-content img').each(function () {
		jQuery(this).width(jQuery(this).width());
	});
});
*/

jQuery(function ($){
	$('body').on('click','.entry-content img',function () {
		var img_zoom=$(this).parent('.img-zoom');
		if (img_zoom.size()>0) {
			img_zoom.addClass('zoom-in');
		}
		var cl=document.documentElement.clientWidth;
		if (cl<768) {
			img_zoom_out();
			return;
		}
		var p=$(this).parent('a');
		if (p.length>0) return;
		if ($(this).hasClass('img_zoom_in')) {
			img_zoom_out();
		}else{
			img_zoom_out();
			var nw=$(this)[0].naturalWidth;
			var w=$(this).width();
			var offset=$(this).offset();
			var st=window.pageYOffset
						|| document.documentElement.scrollTop
						|| document.body.scrollTop
						|| 0;
			if (nw>cl) nw=cl;
			var scale=nw/w;
			var x=(cl-nw)/2-offset.left;
			var y=st-offset.top+58;
			$(this).addClass('img_zoom_in');
			$(this).css({
				'transform':'translate('+x+'px,'+y+'px)',
				'width':nw
			});
			$('.modal-mark').addClass('modal-show');
			$('.modal-mark').addClass('modal-show-for-img');
		}
	});
	$('body').on('click','.modal-mark',img_zoom_out);
	function img_zoom_in() {

	}
	function img_zoom_out() {
		var a=$('.img_zoom_in');
		if(a.length<1) return;
		a.removeClass('img_zoom_in');
		a.css({
			'transform':'none',
		});
		a.width(a.width());
		$('.modal-mark').removeClass('modal-show');
		$('.modal-mark').removeClass('modal-show-for-img');
		var ao=a.offset();
		$('html,body').scrollTop(ao.top-57);
		var img_zoom=a.parent('.img-zoom');
		if (img_zoom.size()>0) {
			img_zoom.removeClass('zoom-in');
		}
	}
});

jQuery(function ($){
	var t=$('.toutiao-content');
	if (t.length<1) return;
	var s=t.children('.date-selects');
	t.append(s.clone().addClass('date-selects-2'));
	$('#sidebar').height($('#content-wrap').height());
});

jQuery(function ($){
	$('.spark_rm').each(function () {
		var span=$(this).children('span');
		var num=0;
		num=Math.floor(Math.random()*span.length);
		span.addClass('hidden');
		span.eq(num).removeClass('hidden').css('visibility','visible');
	});
});

jQuery(function ($){
	$('.img-span').on('click',function () {
		var cl=document.documentElement.clientWidth;
		if (cl<768) return;
		$(this).siblings('img').trigger('click');
	});
});

jQuery(function ($){
	var a=$('#get_pages');
	if (a.length<1) return;
	$(window).on('scroll',orz.scroll(function () {
		var st=window.pageYOffset
					|| document.documentElement.scrollTop
					|| document.body.scrollTop
					|| 0;
		var ct=document.documentElement.clientHeight;
		var ao=a.offset();
		if (st>ao.top-ct+200) {
			a.trigger('click');
		}
	}));
});

//编辑按钮新窗口打开
jQuery(function ($){
	$('body').on('click','.p_edit .btn',function () {
		window.open($(this).attr('href'));
		return false;
	});
});

jQuery(function ($){
	img_zoom_init();
});

(function($){
	function img_zoom_init() {
		$('.img-init img').on('load',function () {
			var $p=$(this).parent();
			var ph=$p.outerHeight();
			var th=$(this).height();
			$(this).css({
				top:0-(th-ph)/2
			});
			$p.removeClass('img-init');
		});
	}
	window.img_zoom_init=img_zoom_init;
})(jQuery);

jQuery(function ($){
	$('body').on('submit','#search-formhybrid-search',function () {
		var $s=$(this).find('[name=s]').val();
		var $q=$(this).find('[name=q]').val();
		window.open('http://so.uisdc.com/cse/search?s='+$s+'&q='+$q);
		return false;
	});
});

//细节猎人首页分享显隐
jQuery(function ($){
	var a=$('.hunter-list-item .btn-share');
	if(a.length<1) return;
	a.on('click',function () {
		var share=$(this).siblings('.share-div');
		if (share.length<1) return;
		if ($(this).hasClass('current')) {
			$(this).removeClass('current');
			share.removeClass('show');
		}else{
			$(this).addClass('current');
			share.addClass('show');
		}
	});
	$('.hunter-list-item .share-div .close').on('click',function () {
		$(this).parent().parent().parent().siblings('.btn-share').trigger('click');
	});
});

//细节猎人首页侧栏自动高度
(function($){
	var s=$('.hunters-content #sidebar-secondary');
	if (s.length<1) return;
	var s2=s.find('.sidebar_right_2');
	if (s2.length<1) return;
	s2.width(s.width());
	$(window).on('resize',function () {
		s2.width(s.width());
	});
})(jQuery);

(function($){
	$('.hunter-show').css('min-height',$('.hunter-show').children('.hunter-single-right').height()-30);
})(jQuery);

jQuery(function ($){
	var fanye=$('.fanye');
	if(fanye.length<1) return;
	var cur=fanye.find('.current_page');
	if(cur.length<1) return;
	var now=+cur.attr('data-current');
	var total=+cur.attr('data-total');
	var btn=fanye.find('.btn');
	if(btn.length<1) return;
	var c=$('.course-items');
	if(c.length<1) return;
	btn.on('click',function () {
		if($(this).hasClass('no')) return;
		if ($(this).hasClass('btn-prev')) {
			now--;
			cur.attr('data-current',now);
			cur.html(now);
			if(now==1) $(this).addClass('no');
			btn.filter('.btn-next').removeClass('no');
		}
		if ($(this).hasClass('btn-next')) {
			now++;
			cur.attr('data-current',now);
			cur.html(now);
			if(now==total) $(this).addClass('no');
			btn.filter('.btn-prev').removeClass('no');
		}
		c.css('top',0-(now-1)*96);
	});
});

jQuery(function ($){
	if (orz.getDevice()=='IE浏览器' || orz.getDevice()=='Edge浏览器') return;
	setInterval(function () {
		$('.dubao .cont a').each(function () {
			var lh=parseFloat($(this).css('line-height'));
			var h=$(this).height();
			var line=Math.ceil(h/lh);
			var unit=h/line;
			var top=parseFloat($(this).css('top'));
			if (top<=unit-h) {
				top=0;
			}else{
				top-=unit;
			}
			$(this).animate({
				'top':top
			},1000);
		});
	},5000);
});

(function($){
	$('body').on('click','.get_share',function () {
		var t=$('.share-div');
		if (t.length<1) return;
		if(t.hasClass('show')) {
			t.removeClass('show');
		}else{
			t.addClass('show');
		}
	});
	$('body').on('click','.post-zt .share-div .close',function () {
		$('.post-zt .share-div').removeClass('show');
	});
})(jQuery);

(function($){
	var a=$('.recom-title>span');
	var b=$('.lists');
	if (a.length<1) return;
	if (b.length<1) return;
	a.on('click',function () {
		a.removeClass('current');
		$(this).addClass('current');
		b.addClass('hidden');
		b.eq(a.index($(this))).removeClass('hidden');
		$('body').trigger('aside_init');
	});
})(jQuery);

/*
(function($){
	mobile_post_menu_init();
	$(window).on('resize',mobile_post_menu_init);
	function mobile_post_menu_init() {
		var cl=document.documentElement.clientWidth;
		if (cl>=768) return;
		var c=$('.post-header-menu');
		if (c.length>0) return;
		var h=$('.current-post-header');
		if (h.length<1) return;
		var m=$('.t-menus');
		if (m.length<1) return;
		h.before('<div class="post-header-menu"><div class="t-menus">'+m.html()+'</div></div>');
	}
})(jQuery);
*/

(function($){
	mobile_post_menu_init();
	$(window).on('resize',mobile_post_menu_init);
	function mobile_post_menu_init() {
		var cl=document.documentElement.clientWidth;
		if (cl>=768) return;
		var c=$('.grouppurchase-div');
		if (c.length>0) return;
		var h=$('.page-wrap');
		if (h.length<1) return;
		var m=$('.grouppurchase-widget');
		if (m.length<1) return;
		var opt=$('<div class="grouppurchase-div"></div>');
		//h.after('<div class="grouppurchase-div"><div class="grouppurchase-widget">'+m.html()+'</div></div>');
		opt.append(m.clone());
		h.after(opt);
		$('body').trigger('djs.reload');
	}
})(jQuery);

(function($){
	var ul=$('.sidebar-post-recommend .reco-items');
	if (ul.length<1) return;
	ul.each(function () {
		var a=$(this).find('a');
		a.each(function () {
			var index=a.index($(this))+1;
			$(this).append('<span class="num">'+index+'</span>');
		});
	});
})(jQuery);

(function($){
	var a=$('.fav_share .share-btn .btn');
	if (a.length<1) return;
	var b=$('.fav_share .share-div');
	if (b.length<1) return;
	a.on('click',function () {
		b.show();
	});
	b.find('li:last').on('click',function () {
		b.hide();
	});
	$(document).on('click',function (e) {
		if (!$(e.target).hasClass('share-btn') && $(e.target).parents('.share-btn').length<1) {
			b.hide();
		}
	});

})(jQuery);

